@@ -40,15 +40,27 @@
 #include "ajax.h"
 
 
-
-
-
 /* ======================================================================= */
 /* ============================ private data ============================= */
 /* ======================================================================= */
 
 
 
+static AjPStr dmxStrline    = NULL;     /* Line of text */
+static AjPStr dmxStrtype    = NULL;
+static AjPStr dmxStrclass   = NULL;
+static AjPStr dmxStrfold    = NULL;
+static AjPStr dmxStrsuper   = NULL;
+static AjPStr dmxStrfamily  = NULL;
+static AjPStr dmxStrarch    = NULL;
+static AjPStr dmxStrtopo    = NULL;
+static AjPStr dmxStrpostsim = NULL;/* Post-similar line */
+static AjPStr dmxStrposttmp = NULL;/* Temp. storage for post-similar line */
+
+static AjPStr dmxStrposisim = NULL;   /* Positions line */
+static AjPStr dmxStrpositmp = NULL;   /* Temp. storage for Positions line */
+static AjPStr dmxStrseq1    = NULL;
+static AjPStr dmxStrcodetmp = NULL;     /* Id code of sequence */
 
 
 /* ======================================================================= */
@@ -128,7 +140,6 @@ AjPScophit ajDmxScophitNew(void)
 
 
 
-
 /* @func ajDmxScopalgNew ****************************************************
 **
 ** Scopalg object constructor. This is normally called by the ajDmxScopalgRead
@@ -162,10 +173,12 @@ AjPScopalg ajDmxScopalgNew(ajint n)
     if(n)
     {
 	AJCNEW0(ret->Codes,n);
+
 	for(i=0;i<n;++i)
 	    ret->Codes[i] = ajStrNew();
 
 	AJCNEW0(ret->Seqs,n);
+
 	for(i=0;i<n;++i)
 	    ret->Seqs[i] = ajStrNew();
     }
@@ -191,34 +204,23 @@ AjPScopalg ajDmxScopalgNew(ajint n)
 
 AjBool ajDmxScopalgRead(AjPFile inf, AjPScopalg *thys)
 {
-    AjBool ok             = ajFalse;  /* True if the file contained 'TY' record. */
-    static AjPStr line    = NULL;     /* Line of text */
-    static AjPStr type    = NULL;
-    static AjPStr class   = NULL;
-    static AjPStr fold    = NULL;
-    static AjPStr super   = NULL;
-    static AjPStr family  = NULL;
-    static AjPStr arch    = NULL;
-    static AjPStr topo    = NULL;
-    static AjPStr postsim = NULL;   /* Post-similar line */
-    static AjPStr posttmp = NULL;   /* Temp. storage for post-similar line */
-
-    static AjPStr posisim = NULL;   /* Positions line */
-    static AjPStr positmp = NULL;   /* Temp. storage for Positions line */
+    AjBool ok = ajFalse;  /* True if the file contained 'TY' record. */
     
     AjBool done_1st_blk   = ajFalse; /* Flag for whether we've read first
 					block of sequences */
 
-    ajint x     = 0;              /* Loop counter */
-    ajint y     = 0;              /* Loop counter */
-    ajint cnt   = 0;              /* Temp. counter of sequence */
-    ajint nseq  = 0;              /* No. of sequences in alignment */
-    ajint Sunid = 0;              /* SCOP Sunid for family */
-    ajint ntok  = 0;              /* No. string tokens in sequence line from alignment.
-				     Sequence start and end may or may not be present, 
-				     therefore ntok is either 2 or 4:
-				     (2)  (ACC       SEQ    ) or 
-				     (4)  (ACC start SEQ end) */
+    ajint x     = 0;   /* Loop counter */
+    ajint y     = 0;   /* Loop counter */
+    ajint cnt   = 0;   /* Temp. counter of sequence */
+    ajint nseq  = 0;   /* No. of sequences in alignment */
+    ajint Sunid = 0;   /* SCOP Sunid for family */
+    ajint ntok  = 0;   /*
+                       ** No. string tokens in sequence line from alignment.
+		       ** Sequence start and end may or may not be present, 
+		       ** therefore ntok is either 2 or 4:
+		       ** (2)  (ACC       SEQ    ) or 
+		       ** (4)  (ACC start SEQ end)
+                       */
     
     
     AjPList list_seqs  = NULL;     /* List of sequences */
@@ -226,8 +228,6 @@ AjBool ajDmxScopalgRead(AjPFile inf, AjPScopalg *thys)
     AjPStr  *arr_seqs  = NULL;     /* Array of sequences */
     AjPStr  seq        = NULL;     
     AjPStr  code       = NULL;     /* Id code of sequence */
-    AjPStr  codetmp    = NULL;     /* Id code of sequence */
-    AjPStr  seq1       = NULL;
 
 
     /* Check args */	
@@ -237,22 +237,22 @@ AjBool ajDmxScopalgRead(AjPFile inf, AjPScopalg *thys)
 
     /* Allocate strings */
     /* Only initialise strings if this is called for the first time */
-    if(!line)
+    if(!dmxStrline)
     {
-	type    = ajStrNew();
-	class   = ajStrNew();
-	fold    = ajStrNew();
-	super   = ajStrNew();
-	family  = ajStrNew();
-	arch    = ajStrNew();
-	topo    = ajStrNew();
-	line    = ajStrNew();
-	postsim = ajStrNew();
-	posttmp = ajStrNew();
-	posisim = ajStrNew();
-	positmp = ajStrNew();
-	seq1    = ajStrNew();
-	codetmp = ajStrNew();
+	dmxStrtype    = ajStrNew();
+	dmxStrclass   = ajStrNew();
+	dmxStrfold    = ajStrNew();
+	dmxStrsuper   = ajStrNew();
+	dmxStrfamily  = ajStrNew();
+	dmxStrarch    = ajStrNew();
+	dmxStrtopo    = ajStrNew();
+	dmxStrline    = ajStrNew();
+	dmxStrpostsim = ajStrNew();
+	dmxStrposttmp = ajStrNew();
+	dmxStrposisim = ajStrNew();
+	dmxStrpositmp = ajStrNew();
+	dmxStrcodetmp = ajStrNew();
+	dmxStrseq1    = ajStrNew();
     }
 
     
@@ -262,114 +262,135 @@ AjBool ajDmxScopalgRead(AjPFile inf, AjPScopalg *thys)
 
 
     /* Read the rest of the file */
-    while(ajFileReadLine(inf,&line))
+    while(ajReadlineTrim(inf,&dmxStrline))
     {
-    	if(ajStrPrefixC(line,"# TY"))
+    	if(ajStrPrefixC(dmxStrline,"# TY"))
 	{
 	    ok = ajTrue;
-	    ajStrAssignC(&type,ajStrGetPtr(line)+5);
-	    ajStrRemoveWhiteExcess(&type);
+	    ajStrAssignC(&dmxStrtype,ajStrGetPtr(dmxStrline)+5);
+	    ajStrRemoveWhiteExcess(&dmxStrtype);
 	}
-    	else if(ajStrPrefixC(line,"# SI"))
+    	else if(ajStrPrefixC(dmxStrline,"# SI"))
 	{
-	    ajFmtScanS(line, "%*s %*s %d", &Sunid);
+	    ajFmtScanS(dmxStrline, "%*s %*s %d", &Sunid);
 	}
-    	else if(ajStrPrefixC(line,"# CL"))
+    	else if(ajStrPrefixC(dmxStrline,"# CL"))
 	{
-	    ajStrAssignC(&class,ajStrGetPtr(line)+5);
-	    ajStrRemoveWhiteExcess(&class);
+	    ajStrAssignC(&dmxStrclass,ajStrGetPtr(dmxStrline)+5);
+	    ajStrRemoveWhiteExcess(&dmxStrclass);
 	}
-	else if(ajStrPrefixC(line,"# FO"))
+	else if(ajStrPrefixC(dmxStrline,"# FO"))
 	{
-	    ajStrAssignC(&fold,ajStrGetPtr(line)+5);
-	    while((ajFileReadLine(inf,&line)))
+	    ajStrAssignC(&dmxStrfold,ajStrGetPtr(dmxStrline)+5);
+
+	    while((ajReadlineTrim(inf,&dmxStrline)))
 	    {
-		if(ajStrPrefixC(line,"# XX"))
+		if(ajStrPrefixC(dmxStrline,"# XX"))
 		    break;
-		ajStrAppendC(&fold,ajStrGetPtr(line)+5);
+
+		ajStrAppendC(&dmxStrfold,ajStrGetPtr(dmxStrline)+5);
 	    }
-	    ajStrRemoveWhiteExcess(&fold);
+
+	    ajStrRemoveWhiteExcess(&dmxStrfold);
 	}
-	else if(ajStrPrefixC(line,"# SF"))
+	else if(ajStrPrefixC(dmxStrline,"# SF"))
 	{
-	    ajStrAssignC(&super,ajStrGetPtr(line)+5);
-	    while((ajFileReadLine(inf,&line)))
+	    ajStrAssignC(&dmxStrsuper,ajStrGetPtr(dmxStrline)+5);
+
+	    while((ajReadlineTrim(inf,&dmxStrline)))
 	    {
-		if(ajStrPrefixC(line,"# XX"))
+		if(ajStrPrefixC(dmxStrline,"# XX"))
 		    break;
-		ajStrAppendC(&super,ajStrGetPtr(line)+5);
+
+		ajStrAppendC(&dmxStrsuper,ajStrGetPtr(dmxStrline)+5);
 	    }
-	    ajStrRemoveWhiteExcess(&super);
+
+	    ajStrRemoveWhiteExcess(&dmxStrsuper);
 	}
-	else if(ajStrPrefixC(line,"# FA"))
+	else if(ajStrPrefixC(dmxStrline,"# FA"))
 	{
-	    ajStrAssignC(&family,ajStrGetPtr(line)+5);
-	    while((ajFileReadLine(inf,&line)))
+	    ajStrAssignC(&dmxStrfamily,ajStrGetPtr(dmxStrline)+5);
+
+	    while((ajReadlineTrim(inf,&dmxStrline)))
 	    {
-		if(ajStrPrefixC(line,"# XX"))
+		if(ajStrPrefixC(dmxStrline,"# XX"))
 		    break;
-		ajStrAppendC(&family,ajStrGetPtr(line)+5);
+
+		ajStrAppendC(&dmxStrfamily,ajStrGetPtr(dmxStrline)+5);
 	    }
-	    ajStrRemoveWhiteExcess(&family);
+
+	    ajStrRemoveWhiteExcess(&dmxStrfamily);
 	}
-	else if(ajStrPrefixC(line,"# AR"))
+	else if(ajStrPrefixC(dmxStrline,"# AR"))
 	{
-	    ajStrAssignC(&arch,ajStrGetPtr(line)+5);
-	    while((ajFileReadLine(inf,&line)))
+	    ajStrAssignC(&dmxStrarch,ajStrGetPtr(dmxStrline)+5);
+
+	    while((ajReadlineTrim(inf,&dmxStrline)))
 	    {
-		if(ajStrPrefixC(line,"# XX"))
+		if(ajStrPrefixC(dmxStrline,"# XX"))
 		    break;
-		ajStrAppendC(&arch,ajStrGetPtr(line)+5);
+
+		ajStrAppendC(&dmxStrarch,ajStrGetPtr(dmxStrline)+5);
 	    }
-	    ajStrRemoveWhiteExcess(&arch);
+
+	    ajStrRemoveWhiteExcess(&dmxStrarch);
 	}
-	else if(ajStrPrefixC(line,"# TP"))
+	else if(ajStrPrefixC(dmxStrline,"# TP"))
 	{
-	    ajStrAssignC(&topo,ajStrGetPtr(line)+5);
-	    while((ajFileReadLine(inf,&line)))
+	    ajStrAssignC(&dmxStrtopo,ajStrGetPtr(dmxStrline)+5);
+
+	    while((ajReadlineTrim(inf,&dmxStrline)))
 	    {
-		if(ajStrPrefixC(line,"# XX"))
+		if(ajStrPrefixC(dmxStrline,"# XX"))
 		    break;
-		ajStrAppendC(&topo,ajStrGetPtr(line)+5);
+
+		ajStrAppendC(&dmxStrtopo,ajStrGetPtr(dmxStrline)+5);
 	    }
-	    ajStrRemoveWhiteExcess(&topo);
+
+	    ajStrRemoveWhiteExcess(&dmxStrtopo);
 	}
-	else if(ajStrPrefixC(line,"# XX"))
+	else if(ajStrPrefixC(dmxStrline,"# XX"))
 	    continue;
-	else if (ajStrPrefixC(line,"# Post_similar"))
+	else if (ajStrPrefixC(dmxStrline,"# Post_similar"))
 	{
 	    /* Parse post_similar line */
-	    ajFmtScanS(line, "%*s %*s %S", &posttmp);
+	    ajFmtScanS(dmxStrline, "%*s %*s %S", &dmxStrposttmp);
+
 	    if(done_1st_blk == ajTrue)
-		ajStrAppendS(&postsim, posttmp);
+		ajStrAppendS(&dmxStrpostsim, dmxStrposttmp);
 	    else
-		ajStrAssignS(&postsim, posttmp);
+		ajStrAssignS(&dmxStrpostsim, dmxStrposttmp);
 	    
 	    continue;
 	}
-	else if (ajStrPrefixC(line,"# Positions"))
+	else if (ajStrPrefixC(dmxStrline,"# Positions"))
 	{
 	    /* Parse Positions line */
-	    ajFmtScanS(line, "%*s %*s %S", &positmp);
+	    ajFmtScanS(dmxStrline, "%*s %*s %S", &dmxStrpositmp);
+
 	    if(done_1st_blk == ajTrue)
-		ajStrAppendS(&posisim, positmp);
+		ajStrAppendS(&dmxStrposisim, dmxStrpositmp);
 	    else
-		ajStrAssignS(&posisim, positmp);
+		ajStrAssignS(&dmxStrposisim, dmxStrpositmp);
 	    
 	    continue;
 	}
 	/* Ignore any other line beginning with '#' which are 
 	   taken to be comments, e.g. 'Number' lines */
-	else if((ajStrPrefixC(line,"#")))
+	else if((ajStrPrefixC(dmxStrline,"#")))
 	    continue;
 	/* ajFileReadLine will have trimmed the tailing \n */
-	else if(ajStrGetCharPos(line,1)=='\0')
+	else if(ajStrGetCharPos(dmxStrline,1)=='\0')
 	{ 
-	    /* The first blank line therefore we've done the first block of sequences*/
+            /*
+            ** The first blank line therefore the first block of sequences
+            ** has been done
+            */
 	    
 	    if(!ok)
 	    {
-		ajWarn("ajDmxScopalgRead but file was not identified as being a domain alignment file");
+		ajWarn("ajDmxScopalgRead but file was not identified as "
+                       "being a domain alignment file");
 		return ajFalse;
 	    }
 
@@ -387,7 +408,8 @@ AjBool ajDmxScopalgRead(AjPFile inf, AjPScopalg *thys)
 	    /* Line of sequence */
 	    if(!ok)
 	    {
-		ajWarn("ajDmxScopalgRead but file was not identified as being a domain alignment file");
+		ajWarn("ajDmxScopalgRead but file was not identified as "
+                       "being a domain alignment file");
 		return ajFalse;
 	    }
 
@@ -396,13 +418,13 @@ AjBool ajDmxScopalgRead(AjPFile inf, AjPScopalg *thys)
 	    {
 		/* already read in the first block of sequences */
 		if(ntok == 4)
-		    ajFmtScanS(line, "%*s %*s %S", &seq1);
+		    ajFmtScanS(dmxStrline, "%*s %*s %S", &dmxStrseq1);
 		else if(ntok == 2)
-		    ajFmtScanS(line, "%*s %S", &seq1);
+		    ajFmtScanS(dmxStrline, "%*s %S", &dmxStrseq1);
 		else 	
 		    ajFatal("ajDmxScopalgRead could not parse alignment");
 
-		ajStrAppendS(&arr_seqs[cnt], seq1);
+		ajStrAppendS(&arr_seqs[cnt], dmxStrseq1);
 		cnt++;
 		continue;
 	    }	
@@ -412,10 +434,11 @@ AjBool ajDmxScopalgRead(AjPFile inf, AjPScopalg *thys)
 		nseq++;
 		seq = ajStrNew();		
 		code = ajStrNew();		
-		if(((ntok = ajStrParseCountC(line, " ")) == 4))
-		    ajFmtScanS(line, "%S %*s %S", &code, &seq);
+
+		if(((ntok = ajStrParseCountC(dmxStrline, " ")) == 4))
+		    ajFmtScanS(dmxStrline, "%S %*s %S", &code, &seq);
 		else if(ntok == 2)
-		    ajFmtScanS(line, "%S %S", &code, &seq);
+		    ajFmtScanS(dmxStrline, "%S %S", &code, &seq);
 		else 	
 		    ajFatal("ajDmxScopalgRead could not parse alignment");
 
@@ -429,7 +452,9 @@ AjBool ajDmxScopalgRead(AjPFile inf, AjPScopalg *thys)
     
     if(!ok)
     {
-	ajWarn("ajDmxScopalgRead but file was not identified as being a domain alignment file");
+	ajWarn("ajDmxScopalgRead but file was not identified as being "
+               "a domain alignment file");
+
 	return ajFalse;
     }
 
@@ -447,7 +472,7 @@ AjBool ajDmxScopalgRead(AjPFile inf, AjPScopalg *thys)
     if(!done_1st_blk && nseq)
 	ajListstrToarray(list_seqs, &arr_seqs);
 
-    ajStrDel(&seq1);
+    ajStrDel(&dmxStrseq1);
     
     if(!nseq)
 	ajWarn("No sequences in alignment !\n");
@@ -458,17 +483,17 @@ AjBool ajDmxScopalgRead(AjPFile inf, AjPScopalg *thys)
 
 
     /* Assign domain records */
-    if(ajStrMatchC(type, "SCOP"))
+    if(ajStrMatchC(dmxStrtype, "SCOP"))
 	(*thys)->Type = ajSCOP;
-    else if(ajStrMatchC(type, "CATH"))
+    else if(ajStrMatchC(dmxStrtype, "CATH"))
 	(*thys)->Type = ajCATH;
 
-    ajStrAssignS(&(*thys)->Class,class);
-    ajStrAssignS(&(*thys)->Architecture,arch);
-    ajStrAssignS(&(*thys)->Topology,topo);
-    ajStrAssignS(&(*thys)->Fold,fold);
-    ajStrAssignS(&(*thys)->Superfamily,super);
-    ajStrAssignS(&(*thys)->Family,family); 
+    ajStrAssignS(&(*thys)->Class,dmxStrclass);
+    ajStrAssignS(&(*thys)->Architecture,dmxStrarch);
+    ajStrAssignS(&(*thys)->Topology,dmxStrtopo);
+    ajStrAssignS(&(*thys)->Fold,dmxStrfold);
+    ajStrAssignS(&(*thys)->Superfamily,dmxStrsuper);
+    ajStrAssignS(&(*thys)->Family,dmxStrfamily); 
     (*thys)->Sunid_Family = Sunid;
     
 
@@ -489,18 +514,18 @@ AjBool ajDmxScopalgRead(AjPFile inf, AjPScopalg *thys)
 	(*thys)->width = ajStrGetLen((*thys)->Seqs[0]);
 	
 	
-	for(x=0; ajListstrPop(list_codes,&codetmp); x++)
+	for(x=0; ajListstrPop(list_codes,&dmxStrcodetmp); x++)
 	{
-	    ajStrAssignS(&(*thys)->Codes[x],codetmp);
-	    ajStrDel(&codetmp);
+	    ajStrAssignS(&(*thys)->Codes[x],dmxStrcodetmp);
+	    ajStrDel(&dmxStrcodetmp);
 	}
 	
 	
 	/* Assign Post_similar line */
-	ajStrAssignS(&(*thys)->Post_similar,postsim); 
+	ajStrAssignS(&(*thys)->Post_similar,dmxStrpostsim); 
 
 	/* Assign Positions line */
-	ajStrAssignS(&(*thys)->Positions,posisim); 
+	ajStrAssignS(&(*thys)->Positions,dmxStrposisim); 
     }
     else 
 	ajWarn("ajDmxScopalgRead called but no sequences found.");
@@ -515,7 +540,6 @@ AjBool ajDmxScopalgRead(AjPFile inf, AjPScopalg *thys)
 
 
 
-
 /* ======================================================================= */
 /* =========================== destructors =============================== */
 /* ======================================================================= */
@@ -567,7 +591,6 @@ void ajDmxScophitDel(AjPScophit *pthis)
 
 
 
-
 /* @func ajDmxScophitDelWrap ************************************************
 **
 ** Wrapper to destructor for Scophit object for use with generic functions.
@@ -591,7 +614,6 @@ void ajDmxScophitDelWrap(void  **ptr)
 
 
 
-
 /* @func ajDmxScopalgDel ****************************************************
 **
 ** Destructor for Scopalg object.
@@ -608,6 +630,7 @@ void ajDmxScopalgDel(AjPScopalg *pthis)
 
     if(!pthis)
 	return;
+
     if(!(*pthis))
 	return;
     
@@ -640,7 +663,6 @@ void ajDmxScopalgDel(AjPScopalg *pthis)
 
 
 
-
 /* ======================================================================= */
 /* ============================ Assignments ============================== */
 /* ======================================================================= */
@@ -707,7 +729,6 @@ AjPList ajDmxScophitListCopy(const AjPList ptr)
 
 
 
-
 /* @func ajDmxScophitCopy ***************************************************
 **
 ** Copies the contents from one Scophit object to another.
@@ -758,7 +779,6 @@ AjBool ajDmxScophitCopy(AjPScophit *to, const AjPScophit from)
 
 
 
-
 /* ======================================================================= */
 /* ============================= Modifiers =============================== */
 /* ======================================================================= */
@@ -797,7 +817,6 @@ AjBool ajDmxScophitTargetLowPriority(AjPScophit *h)
 
 
 
-
 /* @func ajDmxScophitTarget2 ************************************************
 **
 ** Sets the Target2 element of a Scophit object to True.
@@ -825,7 +844,6 @@ AjBool ajDmxScophitTarget2(AjPScophit *h)
 
 
 
-
 /* @func ajDmxScophitTarget *************************************************
 **
 ** Sets the Target element of a Scophit object to True.
@@ -852,7 +870,6 @@ AjBool ajDmxScophitTarget(AjPScophit *h)
 
 
 
-
 /* ======================================================================= */
 /* ========================== Operators ===================================*/
 /* ======================================================================= */
@@ -883,7 +900,6 @@ AjBool ajDmxScophitCheckTarget(const AjPScophit ptr)
 
 
 
-
 /* ======================================================================= */
 /* ============================== Casts ===================================*/
 /* ======================================================================= */
@@ -900,7 +916,6 @@ AjBool ajDmxScophitCheckTarget(const AjPScophit ptr)
 
 
 
-
 /* ======================================================================= */
 /* =========================== Reporters ==================================*/
 /* ======================================================================= */
@@ -915,7 +930,6 @@ AjBool ajDmxScophitCheckTarget(const AjPScophit ptr)
 
 
 
-
 /* @func ajDmxScophitCompScore **********************************************
 **
 ** Function to sort Scophit objects by Score element. Usually called by 
@@ -947,7 +961,6 @@ ajint ajDmxScophitCompScore(const void *hit1, const void *hit2)
 
 
 
-
 /* @func ajDmxScophitCompPval ***********************************************
 **
 ** Function to sort AjOScophit objects by Pval record. Usually called by 
@@ -979,7 +992,6 @@ ajint ajDmxScophitCompPval(const void *hit1, const void *hit2)
 
 
 
-
 /* @func ajDmxScophitCompAcc ************************************************
 **
 ** Function to sort Scophit objects by Acc element. 
@@ -1010,7 +1022,6 @@ ajint ajDmxScophitCompAcc(const void *hit1, const void *hit2)
 
 
 
-
 /* @func ajDmxScophitCompSunid **********************************************
 **
 ** Function to sort Scophit object by Sunid_Family.
@@ -1043,7 +1054,6 @@ ajint ajDmxScophitCompSunid(const void *entry1, const void *entry2)
 
 
 
-
 /* @func ajDmxScophitCompSpr ************************************************
 **
 ** Function to sort Scophit object by Spr element. 
@@ -1071,8 +1081,6 @@ ajint ajDmxScophitCompSpr(const void *hit1, const void *hit2)
 
 
 
-
-
 /* @func ajDmxScophitCompEnd ************************************************
 **
 ** Function to sort Scophit object by End element. 
@@ -1113,7 +1121,6 @@ ajint ajDmxScophitCompEnd(const void *hit1, const void *hit2)
 
 
 
-
 /* @func ajDmxScophitCompStart **********************************************
 **
 ** Function to sort Scophit object by Start element. 
@@ -1149,7 +1156,6 @@ ajint ajDmxScophitCompStart(const void *hit1, const void *hit2)
 
 
 
-
 /* @func ajDmxScophitCompFam ************************************************
 **
 ** Function to sort Scophit object by Family element. 
@@ -1176,7 +1182,6 @@ ajint ajDmxScophitCompFam(const void *hit1, const void *hit2)
 
 
 
-
 /* @func ajDmxScophitCompSfam ***********************************************
 **
 ** Function to sort Scophit object by Superfamily  element. 
@@ -1214,6 +1219,7 @@ ajint ajDmxScophitCompSfam(const void *hit1, const void *hit2)
 ** should sort first. 0 if they are identical.
 ** @@
 ****************************************************************************/
+
 ajint ajDmxScophitCompClass(const void *hit1, const void *hit2)
 {
     AjPScophit p = NULL;
@@ -1228,7 +1234,6 @@ ajint ajDmxScophitCompClass(const void *hit1, const void *hit2)
 
 
 
-
 /* @func ajDmxScophitCompFold ***********************************************
 **
 ** Function to sort Scophit object by Fold element. 
@@ -1240,6 +1245,7 @@ ajint ajDmxScophitCompClass(const void *hit1, const void *hit2)
 ** should sort first. 0 if they are identical.
 ** @@
 ****************************************************************************/
+
 ajint ajDmxScophitCompFold(const void *hit1, const void *hit2)
 {
     AjPScophit p = NULL;
@@ -1254,7 +1260,6 @@ ajint ajDmxScophitCompFold(const void *hit1, const void *hit2)
 
 
 
-
 /* ======================================================================= */
 /* ========================== Input & Output ============================= */
 /* ======================================================================= */
@@ -1270,6 +1275,7 @@ ajint ajDmxScophitCompFold(const void *hit1, const void *hit2)
 ** @return [ajint] Number of sequences read
 ** @@
 ****************************************************************************/
+
 ajint ajDmxScopalgGetseqs(const AjPScopalg thys, AjPStr **arr)
 {
     ajuint i;
@@ -1437,6 +1443,8 @@ AjBool ajDmxScophitsWrite(AjPFile outf, const AjPList list)
 }
 
 
+
+
 /* @func ajDmxScophitsWriteFasta ********************************************
 **
 ** Write contents of a list of Scophits to an output file in DHF format
@@ -1547,6 +1555,8 @@ AjBool ajDmxScophitsWriteFasta(AjPFile outf, const AjPList list)
 }
 
 
+
+
 /* @func ajDmxScophitReadFasta **********************************************
 **
 ** Read a Scophit object from a file in extended FASTA format 
@@ -1576,7 +1586,7 @@ AjPScophit ajDmxScophitReadFasta(AjPFile inf)
     subline  = ajStrNew();
     type     = ajStrNew();
 
-    while((ajFileReadLine(inf,&line)))
+    while((ajReadlineTrim(inf,&line)))
     {
 	if(ajStrPrefixC(line,">"))
 	{
@@ -1587,6 +1597,7 @@ AjPScophit ajDmxScophitReadFasta(AjPFile inf)
 		ajStrDel(&line);
 		ajStrDel(&subline);
 		ajStrDel(&type);
+
 		return hit;
 	    }	
 	    else
@@ -1594,6 +1605,7 @@ AjPScophit ajDmxScophitReadFasta(AjPFile inf)
 
 	    /* Check line has correct no. of tokens and allocate Hit */
 	    ajStrAssignSubS(&subline, line, 1, -1);
+
 	    if( (ntok=ajStrParseCountC(subline, "^")) != 17)
 	    {
 		ajWarn("Wrong no. (%d) of tokens for a DHF file on line %S\n", ntok, line);
@@ -1608,12 +1620,14 @@ AjPScophit ajDmxScophitReadFasta(AjPFile inf)
 	    token = ajStrParseC(subline, "^");
 	    ajStrAssignS(&hit->Acc, token);
 	    ajStrTrimWhite(&hit->Acc); 
+
 	    if(ajStrMatchC(hit->Acc, "."))
 		ajStrSetClear(&hit->Acc);
 	    	    
 	    /* Spr */
 	    token = ajStrParseC(NULL, "^");
 	    ajStrAssignS(&hit->Spr, token);
+
 	    if(ajStrMatchC(hit->Spr, "."))
 		ajStrSetClear(&hit->Spr);
 
@@ -1628,6 +1642,7 @@ AjPScophit ajDmxScophitReadFasta(AjPFile inf)
 	    /* Type */
 	    token = ajStrParseC(NULL, "^");
 	    ajStrAssignS(&type, token);
+
 	    if(ajStrMatchC(type, "SCOP"))
 		hit->Type = ajSCOP;
 	    else if(ajStrMatchC(type, "CATH"))
@@ -1636,6 +1651,7 @@ AjPScophit ajDmxScophitReadFasta(AjPFile inf)
 	    /* Dom */
 	    token = ajStrParseC(NULL, "^");
 	    ajStrAssignS(&hit->Dom, token);
+
 	    if(ajStrMatchC(hit->Dom, "."))
 		ajStrSetClear(&hit->Dom);
 
@@ -1645,11 +1661,13 @@ AjPScophit ajDmxScophitReadFasta(AjPFile inf)
 
 	    token = ajStrParseC(NULL, "^");
 	    ajStrAssignS(&hit->Class, token);
+
 	    if(ajStrMatchC(hit->Class, "."))
 		ajStrSetClear(&hit->Class);		
 
 	    token = ajStrParseC(NULL, "^");
 	    ajStrAssignS(&hit->Architecture, token);
+
 	    if(ajStrMatchC(hit->Architecture, "."))
 		ajStrSetClear(&hit->Architecture);
 
@@ -1660,21 +1678,25 @@ AjPScophit ajDmxScophitReadFasta(AjPFile inf)
 
 	    token = ajStrParseC(NULL, "^");
 	    ajStrAssignS(&hit->Fold, token);
+
 	    if(ajStrMatchC(hit->Fold, "."))
 		ajStrSetClear(&hit->Fold);
 
 	    token = ajStrParseC(NULL, "^");
 	    ajStrAssignS(&hit->Superfamily, token);
+
 	    if(ajStrMatchC(hit->Superfamily, "."))
 		ajStrSetClear(&hit->Superfamily);
 
 	    token = ajStrParseC(NULL, "^");
 	    ajStrAssignS(&hit->Family, token);
+
 	    if(ajStrMatchC(hit->Family, "."))
 		ajStrSetClear(&hit->Family);
 
 	    token = ajStrParseC(NULL, "^");
 	    ajStrAssignS(&hit->Model, token);
+
 	    if(ajStrMatchC(hit->Model, "."))
 		ajStrSetClear(&hit->Model);
 
@@ -1712,6 +1734,7 @@ AjPScophit ajDmxScophitReadFasta(AjPFile inf)
     ajStrDel(&subline);
     ajStrDel(&type);
     ajDmxScophitDel(&hit);
+
     return NULL;
 }
 
@@ -1774,6 +1797,7 @@ AjBool ajDmxScopalgWrite(const AjPScopalg scop, AjPFile outf)
     AjPInt    idx  = NULL;  /* Index */
     
     idx = ajIntNewL(scop->N); 
+
     for(x=0; x<scop->N; x++)
 	ajIntPut(&idx, scop->N, 1);
 
@@ -1810,7 +1834,8 @@ AjBool ajDmxScopalgWrite(const AjPScopalg scop, AjPFile outf)
 	ajFmtPrintSplit(outf,scop->Superfamily,"# SF   ",75," \t\n\r");
 	ajFmtPrintF(outf, "# XX\n");
 
-	/* ajFmtPrintSplit(outf,scop->Architecture,"\nXX\n# AR   ",75," \t\n\r");
+	/* ajFmtPrintSplit(outf,scop->Architecture,
+                           "\nXX\n# AR   ",75," \t\n\r");
 	ajFmtPrintSplit(outf,scop->Topology,"# XX\n# TP   ",75," \t\n\r");
 	ajFmtPrintSplit(outf,scop->Superfamily,"# XX\n# SF   ",75," \t\n\r");
 	ajFmtPrintF(outf,"# XX\n"); */
@@ -1836,6 +1861,7 @@ AjBool ajDmxScopalgWrite(const AjPScopalg scop, AjPFile outf)
     {
 	start = x*50;
 	end   = start + 49;
+
 	if(end>=scop->width)
 	    end = scop->width - 1;
 	
@@ -1868,8 +1894,6 @@ AjBool ajDmxScopalgWrite(const AjPScopalg scop, AjPFile outf)
 
 
 
-
-
 /* @func ajDmxScopalgWriteClustal *******************************************
 **
 ** Writes a Scopalg object to a specified file in CLUSTAL format (just the 
@@ -1899,6 +1923,7 @@ AjBool ajDmxScopalgWriteClustal(const AjPScopalg align, AjPFile outf)
 
     for(i=0;i<align->N;++i)
     	ajFmtPrintF(outf,"%S_%d   %S\n",align->Codes[i],i,align->Seqs[i]);
+
     ajFmtPrintF(outf,"\n");
     ajFmtPrintF(outf,"\n"); 
     
@@ -1908,7 +1933,6 @@ AjBool ajDmxScopalgWriteClustal(const AjPScopalg align, AjPFile outf)
 
 
 
-
 /* @func ajDmxScopalgWriteClustal2 ******************************************
 **
 ** Writes a Scopalg object to a specified file in CLUSTAL format (just the 
@@ -1937,6 +1961,7 @@ AjBool ajDmxScopalgWriteClustal2(const AjPScopalg align, AjPFile outf)
 
     for(i=0;i<align->N;++i)
     	ajFmtPrintF(outf,"%S_%d   %S\n",align->Codes[i],i,align->Seqs[i]);
+
     ajFmtPrintF(outf,"\n");
     
     return ajTrue;
@@ -1945,7 +1970,6 @@ AjBool ajDmxScopalgWriteClustal2(const AjPScopalg align, AjPFile outf)
 
 
 
-
 /* @func ajDmxScopalgWriteFasta ********************************************
 **
 ** Writes a Scopalg object to a specified file in FASTA format (just the 
@@ -1957,6 +1981,7 @@ AjBool ajDmxScopalgWriteClustal2(const AjPScopalg align, AjPFile outf)
 ** @return [AjBool] True on success (a file has been written)
 ** @@
 ****************************************************************************/
+
 AjBool ajDmxScopalgWriteFasta(const AjPScopalg align, AjPFile outf)
 {
     ajuint i;
@@ -1974,6 +1999,7 @@ AjBool ajDmxScopalgWriteFasta(const AjPScopalg align, AjPFile outf)
 
     for(i=0;i<align->N;++i)
     	ajFmtPrintF(outf,">%S_%d\n%S\n",align->Codes[i],i,align->Seqs[i]);
+
     ajFmtPrintF(outf,"\n");
     ajFmtPrintF(outf,"\n"); 
     
@@ -1983,7 +2009,6 @@ AjBool ajDmxScopalgWriteFasta(const AjPScopalg align, AjPFile outf)
 
 
 
-
 /* ======================================================================= */
 /* ======================== Miscellaneous =================================*/
 /* ======================================================================= */
@@ -2024,6 +2049,7 @@ AjBool ajDmxScopSeqFromSunid(ajint id, AjPStr *seq, const AjPList list)
     }
       
     dim = ajListToarray(list, (void ***) &(arr));
+
     if(!dim)
     {
         ajWarn("Empty list passed to ajDmxScopSeqFromSunid");
@@ -2050,6 +2076,35 @@ AjBool ajDmxScopSeqFromSunid(ajint id, AjPStr *seq, const AjPList list)
 
 
 
+/* @func ajDmxExit ************************************************************
+**
+** Cleanup of Dmx function internals.
+**
+** @return [void]
+** @@
+******************************************************************************/
+
+void ajDmxExit(void)
+{
+    ajStrDel(&dmxStrline);
+    ajStrDel(&dmxStrtype);
+    ajStrDel(&dmxStrclass);
+    ajStrDel(&dmxStrfold);
+    ajStrDel(&dmxStrsuper);
+    ajStrDel(&dmxStrfamily);
+    ajStrDel(&dmxStrarch);
+    ajStrDel(&dmxStrtopo);
+    ajStrDel(&dmxStrpostsim);
+    ajStrDel(&dmxStrposttmp);
+    ajStrDel(&dmxStrposisim);
+    ajStrDel(&dmxStrpositmp);
+    ajStrDel(&dmxStrseq1);
+    ajStrDel(&dmxStrcodetmp);
+}
+
+
+
+
 /* @func ajDmxDummyFunction ***************************************************
 **
 ** Dummy function to catch all unused functions defined in the ajdmx
@@ -2083,5 +2138,6 @@ static void dmxTraceScophit(const AjPScophit scophit, const char* title)
     ajDebug("Acc: '%S'\n", scophit->Acc);
     ajDebug("Start: %d\n", scophit->Start);
     ajDebug("End: %d\n", scophit->End);
+
     return;
 }
