@@ -663,7 +663,9 @@ static void cvt_c(ajint code, VALIST ap, int put(int c, void* cl), void* cl,
 
     if(!minusflag)
 	pad(width - 1, ' ');
+
     put(ajSysCastItouc(va_arg(VA_V(ap), int)), cl);
+
     if(minusflag)
 	pad(width - 1, ' ');
 
@@ -718,6 +720,7 @@ static void cvt_f(ajint code, VALIST ap, int put(int c, void* cl), void* cl,
 	ajint i = 2;
 
 	assert(precision <= 99);
+
 	if(precision > 9)
 	    fmt[i++] = ajSysCastItoc((precision/10)%10 + '0');
 	fmt[i++] = ajSysCastItoc(precision%10 + '0');
@@ -725,11 +728,9 @@ static void cvt_f(ajint code, VALIST ap, int put(int c, void* cl), void* cl,
 	fmt[i]   = '\0';
 
 	sprintf(buf, fmt, va_arg(VA_V(ap), double));
+
 	if(code == 'g')
-	{
-	    if(width == INT_MIN && (ajuint) precision > strlen(buf))
-		precision = strlen(buf);
-	}
+            precision = 0;
     }
 
     /* now write string and support width */
@@ -1018,6 +1019,9 @@ static Fmt_S scvt[256] =
  /* 120-127 */ scvt_x,     0,scvt_z,     0,     0,     0,     0,     0
 };
 
+
+
+
 /* ****************************************************************************
 **
 ** Legal flag characters for conversions:
@@ -1079,6 +1083,7 @@ static ajint fmtInsert(int c, void* cl)
 	p->bp = p->buf + p->size;
 	p->size *= 2;
     }
+
     *p->bp++ = ajSysCastItoc(c);
 
     return c;
@@ -1111,6 +1116,7 @@ static ajint fmtAppend(ajint c, void* cl)
 	p->bp = p->buf + p->size;
 	p->size *= 2;
     }
+
     *p->bp++ = ajSysCastItoc(c);
 
     return c;
@@ -1163,6 +1169,7 @@ void ajFmtPuts(const char* str, ajint len, int put(int c, void* cl), void* cl,
 	pad(width - len, ' ');
     {
 	ajint i;
+
 	for(i = 0; i < len; i++)
 	    put((unsigned char)*str++, cl);
     }
@@ -1409,6 +1416,7 @@ ajint ajFmtVPrintCL(char* buf, ajint size, const char* fmt, va_list ap)
     ajint len;
 
     len = ajFmtVfmtCL(buf, size, fmt, ap);
+
     return len;
 }
 
@@ -1440,6 +1448,7 @@ ajint ajFmtPrintCL(char* buf, ajint size, const char* fmt, ...)
     va_start(ap, fmt);
     len = ajFmtVfmtCL(buf, size, fmt, ap);
     va_end(ap);
+
     return len;
 }
 
@@ -1487,6 +1496,7 @@ AjPStr ajFmtStr(const char* fmt, ...)
 #endif
 
     va_end(ap);
+
     return fnew;
 }
 
@@ -1801,6 +1811,7 @@ void ajFmtVfmt(int put(int c, void* cl), void* cl, const char* fmt,
 	    {
 		/* look for any conversion flags */
 		unsigned char cc = *fmt;
+
 		for( ; (int)cc && strchr(Fmt_flags, cc); cc = *++fmt)
 		{
 		    assert(flags[(int)cc] < 255);
@@ -1826,6 +1837,7 @@ void ajFmtVfmt(int put(int c, void* cl), void* cl, const char* fmt,
 			assert(n <= (INT_MAX - d)/10);
 			n = 10*n + d;
 		    }
+
 		width = n;
 	    }
 
@@ -1846,6 +1858,7 @@ void ajFmtVfmt(int put(int c, void* cl), void* cl, const char* fmt,
 			assert(n <= (INT_MAX - d)/10);
 			n = 10*n + d;
 		    }
+
 		precision = n;
 	    }
 
@@ -1857,6 +1870,7 @@ void ajFmtVfmt(int put(int c, void* cl), void* cl, const char* fmt,
 		flags[(int)*fmt]++;
 		fmt++;
 	    }
+
 	    /* finally, next character is the code */
 	    c = *fmt++;
 
@@ -1996,8 +2010,9 @@ void ajFmtPutd(const char* str, ajint len, int put(int c, void* cl), void* cl,
 		put(sign, cl);
 	}
 
-	/* pad after end */
+	/* pad for precision - should be turned off for %g */
 	pad(precision - len, '0');
+
 	{
 	    ajint i;
 
@@ -2058,7 +2073,9 @@ void ajFmtPrintSplit(AjPFile outf, const AjPStr str,
 	{
 	    if(c++)
 		ajStrAppendC(&tmp," ");
+
 	    ajStrAppendS(&tmp,token);
+
 	    if(c!=1)
 		n = ++l;
 	    else
@@ -2210,7 +2227,7 @@ ajint ajFmtScanF(AjPFile thys, const char* fmt, ...)
     if(!thys)
 	return 0;
 
-    file = ajFileFp(thys);
+    file = ajFileGetFileptr(thys);
 
     va_start(ap, fmt);
 
@@ -2272,6 +2289,7 @@ static ajint fmtVscan(const char *thys,const char *fmt,va_list ap)
 	    ++p;
 	    continue;
 	}
+
 	if(c_isin((ajint)*q,wspace))
 	{
 	    ++q;
@@ -2356,7 +2374,6 @@ static ajint fmtVscan(const char *thys,const char *fmt,va_list ap)
 	++q;
     }
 
-
     return n;
 }
 
@@ -2463,7 +2480,9 @@ static void scvt_d(const char *fmt, const char **pos, VALIST ap, ajint width,
 		val = (long *) va_arg(VA_V(ap), long *);
 	    else
 		hval = (ajlong *) va_arg(VA_V(ap), ajlong *);
+
 	    ajStrAssignSubC(&t,p,0,q-p-1);
+
 	    if(flag!='L')
 		sscanf(ajStrGetPtr(t),"%ld",&n);
 
@@ -2547,12 +2566,15 @@ static void scvt_x(const char *fmt, const char **pos, VALIST ap, ajint width,
 		val = (unsigned long *) va_arg(VA_V(ap), unsigned long *);
 	    else
 		hval = (ajulong *) va_arg(VA_V(ap), ajulong *);
+
 	    ajStrAssignSubC(&t,p,0,q-p-1);
+
 	    if(flag!='L')
 	    {
 		if(sscanf(ajStrGetPtr(t),"%lx",&n)!=1)
 		{
 		    ajStrDel(&t);
+
 		    return;
 		}
 	    }
@@ -2562,11 +2584,15 @@ static void scvt_x(const char *fmt, const char **pos, VALIST ap, ajint width,
 		hn = sc_hex(ajStrGetPtr(t));
 #else
 		val = (unsigned long *) hval;
+
 		if(sscanf(ajStrGetPtr(t),"%lx",&n)!=1)
 		{
 		    ajStrDel(&t);
+
 		    return;
 		}
+
+
 		hn = n;
 		/*ajDebug("Warning: Use of %%Lx on a 32 bit model");*/
 #endif
@@ -2638,26 +2664,34 @@ static void scvt_f(const char *fmt, const char **pos, VALIST ap, ajint width,
 	if(convert)
 	{
 	    ajStrAssignSubC(&t,p,0,q-p-1);
+
 	    if(flag=='l')
 	    {
 		val = (double*) va_arg(VA_V(ap), double *);
+
 		if(sscanf(ajStrGetPtr(t),"%lf",&n)!=1)
 		{
 		    ajStrDel(&t);
+
 		    return;
 		}
+
 		*(double *)val = n;
 	    }
 	    else
 	    {
 		fval = (float*) va_arg(VA_V(ap), float *);
+
 		if(sscanf(ajStrGetPtr(t),"%f",&fn)!=1)
 		{
 		    ajStrDel(&t);
+
 		    return;
 		}
+
 		*(float *)fval = fn;
 	    }
+
 	    ajStrDel(&t);
 	}
 
@@ -2777,6 +2811,7 @@ static void scvt_o(const char *fmt, const char **pos, VALIST ap, ajint width,
 		val = (unsigned long *) va_arg(VA_V(ap), unsigned long *);
 	    else
 		hval = (ajulong *)  va_arg(VA_V(ap), ajulong *);
+
 	    ajStrAssignSubC(&t,p,0,q-p-1);
 
 	    if(flag!='L')
@@ -2784,6 +2819,7 @@ static void scvt_o(const char *fmt, const char **pos, VALIST ap, ajint width,
 		if(sscanf(ajStrGetPtr(t),"%lo",&n)!=1)
 		{
 		    ajStrDel(&t);
+
 		    return;
 		}
 	    }
@@ -2793,11 +2829,14 @@ static void scvt_o(const char *fmt, const char **pos, VALIST ap, ajint width,
 		hn = sc_octal(ajStrGetPtr(t));
 #else
 		val = (unsigned long *) hval;
+
 		if(sscanf(ajStrGetPtr(t),"%lo",&n)!=1)
 		{
 		    ajStrDel(&t);
+
 		    return;
 		}
+
 		hn = n;
 		/*ajDebug("Warning: Use of %%Lo on a 32 bit model");*/
 #endif
@@ -2816,6 +2855,7 @@ static void scvt_o(const char *fmt, const char **pos, VALIST ap, ajint width,
 	*pos = q;
 	*ok = ajTrue;
     }
+
     ajStrDel(&t);
 
     return;
@@ -2876,6 +2916,7 @@ static void scvt_u(const char *fmt, const char **pos, VALIST ap, ajint width,
 		val = (unsigned long *) va_arg(VA_V(ap), unsigned long *);
 	    else
 		hval = (ajulong *)  va_arg(VA_V(ap), ajulong *);
+
 	    ajStrAssignSubC(&t,p,0,q-p-1);
 
 	    if(flag!='L')
@@ -2883,6 +2924,7 @@ static void scvt_u(const char *fmt, const char **pos, VALIST ap, ajint width,
 		if(sscanf(ajStrGetPtr(t),"%lu",&n)!=1)
 		{
 		    ajStrDel(&t);
+
 		    return;
 		}
 	    }
@@ -2892,11 +2934,14 @@ static void scvt_u(const char *fmt, const char **pos, VALIST ap, ajint width,
 		hn = sc_ulong(ajStrGetPtr(t));
 #else
 		val = (unsigned long *) hval;
+
 		if(sscanf(ajStrGetPtr(t),"%lu",&n)!=1)
 		{
 		    ajStrDel(&t);
+
 		    return;
 		}
+
 		hn = n;
 		/*ajDebug("Warning: Use of %%Lu on a 32 bit model");*/
 #endif
@@ -2916,6 +2961,7 @@ static void scvt_u(const char *fmt, const char **pos, VALIST ap, ajint width,
 	*pos = q;
 	*ok = ajTrue;
     }
+
     ajStrDel(&t);
 
     return;
@@ -2971,14 +3017,17 @@ static void scvt_p(const char *fmt, const char **pos, VALIST ap, ajint width,
 	{
 	    val = (void **) va_arg(VA_V(ap), void **);
 	    ajStrAssignSubC(&t,p,0,q-p-1);
+
 	    if(sscanf(ajStrGetPtr(t),"%lx",&n)!=1)
 		return;
+
 	    *val = (void *)n;
 	}
 
 	*pos = q;
 	*ok = ajTrue;
     }
+
     ajStrDel(&t);
 
     return;
@@ -3026,24 +3075,30 @@ static void scvt_uB(const char *fmt, const char **pos, VALIST ap, ajint width,
     if(!strncmp(q,"Yes",3))
     {
 	*pos = q+3;
+
 	if(convert)
 	{
 	    val = (AjBool *) va_arg(VA_V(ap), AjBool *);
 	    *(AjBool*)val = ajTrue;
 	}
+
 	*ok = ajTrue;
+
 	return;
     }
 
     if(!strncmp(q,"No",2))
     {
 	*pos = q+2;
+
 	if(convert)
 	{
 	    val = (AjBool *) va_arg(VA_V(ap), AjBool *);
 	    *(AjBool*)val = ajFalse;
 	}
+
 	*ok = ajTrue;
+
 	return;
     }
 
@@ -3055,8 +3110,10 @@ static void scvt_uB(const char *fmt, const char **pos, VALIST ap, ajint width,
 	    val = (AjBool *) va_arg(VA_V(ap), AjBool *);
 	    *(AjBool*)val = ajTrue;
 	}
+
 	*pos = ++q;
 	*ok = ajTrue;
+
 	return;
     }
 
@@ -3067,8 +3124,10 @@ static void scvt_uB(const char *fmt, const char **pos, VALIST ap, ajint width,
 	    val = (AjBool *) va_arg(VA_V(ap), AjBool *);
 	    *(AjBool*)val = ajFalse;
 	}
+
 	*pos = ++q;
 	*ok = ajTrue;
+
 	return;
     }
 
@@ -3086,10 +3145,12 @@ static void scvt_uB(const char *fmt, const char **pos, VALIST ap, ajint width,
 	    val = (AjBool *) va_arg(VA_V(ap), AjBool *);
 	    ajStrAssignSubC(&t,p,0,q-p-1);
 	    sscanf(ajStrGetPtr(t),"%d",&n);
+
 	    if(n)
 		*(AjBool*)val = ajTrue;
 	    else
 		*(AjBool*)val = ajFalse;
+
 	    ajStrDel(&t);
 	}
 
@@ -3189,8 +3250,10 @@ static void scvt_b(const char *fmt, const char **pos, VALIST ap, ajint width,
 	    val = (AjBool *) va_arg(VA_V(ap), AjBool *);
 	    *(AjBool*)val = ajTrue;
 	}
+
 	*pos = ++q;
 	*ok = ajTrue;
+
 	return;
     }
 
@@ -3201,6 +3264,7 @@ static void scvt_b(const char *fmt, const char **pos, VALIST ap, ajint width,
 	    val = (AjBool *) va_arg(VA_V(ap), AjBool *);
 	    *(AjBool*)val = ajFalse;
 	}
+
 	*pos = ++q;
 	*ok = ajTrue;
     }
@@ -3252,8 +3316,10 @@ static void scvt_z(const char *fmt, const char **pos, VALIST ap, ajint width,
 	{
 	    val = (char **) va_arg(VA_V(ap), char **);
 	    ajStrAssignSubC(&t,p,0,q-p-1);
+
 	    if(!*val)
 		*val = ajCharNewRes(ajStrGetLen(t)+1);
+
 	    strcpy(*val,ajStrGetPtr(t));
 	    ajStrDel(&t);
 	}
@@ -3353,6 +3419,7 @@ static ajulong sc_hex(const char *str)
 	    d = c - '0';
 	else
 	    d = c - 'A' + 10;
+
 	v = (ajulong)16*v + (ajulong)d;
     }
 
