@@ -130,6 +130,7 @@ AjPList ajListNew(void)
 
 
 
+
 /* @func ajListNewListref ******************************************************
 **
 ** Copy a list.
@@ -161,6 +162,9 @@ AjPList ajListNewListref(const AjPList list)
     return newlist;
 }
 
+
+
+
 /* @obsolete ajListCopy
 ** @rename ajListNewListref
 */
@@ -174,6 +178,9 @@ __deprecated AjPList ajListCopy(const AjPList list)
 ** @remove Use explicit ajListPush calls instead
 */
 
+
+
+
 __deprecated AjPList ajListNewArgs(void* x, ...)
 {
     AjPList list;
@@ -227,6 +234,8 @@ static AjPList listNew(AjEnum type)
 }
 
 
+
+
 /* @funcstatic listInsertNode *************************************************
 **
 ** Inserts a new node in a list at the current node position.
@@ -345,6 +354,7 @@ void ajListPush(AjPList list, void* x)
 
 
 
+
 /* @func ajListPushAppend *****************************************************
 **
 ** Add a new node at the end of the list and add the
@@ -390,6 +400,8 @@ void ajListPushAppend(AjPList list, void* x)
 }
 
 
+
+
 /* @obsolete ajListPushApp
 ** @rename ajListPushAppend
 */
@@ -400,6 +412,9 @@ __deprecated void ajListPushApp(AjPList list, void* x)
     return;
 }
 
+
+
+
 /* @func ajListPushlist *******************************************************
 **
 ** Adds a list to the start of the current list, then deletes the second list.
@@ -432,6 +447,7 @@ void ajListPushlist(AjPList list, AjPList* Plist)
 
         if(listFreeNext >= listFreeMax)
             listFreeSetExpand();
+
         if(listFreeNext >= listFreeMax)
             AJFREE(list->First);
         else if(list->First)
@@ -456,6 +472,7 @@ void ajListPushlist(AjPList list, AjPList* Plist)
 
 
 
+
 /* @obsolete ajListPushList
 ** @rename ajListPushlist
 */
@@ -466,6 +483,9 @@ __deprecated void ajListPushList(AjPList list, AjPList* pmore)
     return;
 }
 
+
+
+
 /* @section Modifiers **********************************************************
 **
 ** @fdata [AjPList]
@@ -542,6 +562,7 @@ void ajListPurge(AjPList list,
 
 
     iter = ajListIterNew(list);
+
     while((ret=ajListIterGet(iter)))
 	if(test(ret))
 	{
@@ -556,6 +577,8 @@ void ajListPurge(AjPList list,
 }
 
 
+
+
 /* @obsolete ajListGarbageCollect
 ** @replace ajListPurge (1,2,3/1,3,2)
 */
@@ -567,6 +590,9 @@ __deprecated void ajListGarbageCollect(AjPList list, void (*destruct)(void **),
     return;
 }
 
+
+
+
 /* @func ajListReverse ********************************************************
 **
 ** Reverse the order of the nodes in an abstract list.
@@ -599,6 +625,7 @@ void ajListReverse(AjPList list)
 	node->Next = head;
 	head = node;
     }
+
     list->First = head;
 
     list->First->Prev = NULL;
@@ -692,12 +719,14 @@ void ajListSortTwo(AjPList list,
 	while(!sort1(&ptrs[pos],&ptrs[pos+1]))
 	{
 	    ++pos;
+
 	    if(pos>limit)
 		break;
 	}
 	++pos;
 
 	n = pos-base;
+
 	if(n>1)
 	    qsort((void *)&ptrs[base],n,sizeof(void*),sort2);
 
@@ -705,6 +734,7 @@ void ajListSortTwo(AjPList list,
     }
 
     pos = 0;
+
     while(node->Next)
     {
 	node->Item = ptrs[pos++];
@@ -717,6 +747,7 @@ void ajListSortTwo(AjPList list,
 
 
 
+
 /* @obsolete ajListSort2
 ** @rename ajListSortTwo
 */
@@ -726,10 +757,13 @@ __deprecated void ajListSort2(AjPList list,
 			      int (*sort2) (const void*, const void*))
 {
     ajListSortTwo(list, sort1, sort2);
+
     return;
 }
 
 
+
+
 /* @func ajListSortTwoThree ****************************************************
 **
 ** Sort the items in a list using 3 fields in the same object hierarchy.
@@ -774,18 +808,22 @@ void ajListSortTwoThree(AjPList list,
 	      !sort2(&ptrs[pos],&ptrs[pos+1]))
 	{
 	    ++pos;
+
 	    if(pos>limit)
 		break;
 	}
-	++pos;
 
+	++pos;
 	n = pos-base;
+
 	if(n>1)
 	    qsort((void *)&ptrs[base],n,sizeof(void*),sort3);
+
 	base = pos;
     }
 
     pos = 0;
+
     while(node->Next)
     {
 	node->Item = ptrs[pos++];
@@ -793,9 +831,13 @@ void ajListSortTwoThree(AjPList list,
     }
 
     AJFREE(ptrs);
+
     return;
 }
 
+
+
+
 /* @obsolete ajListSort3
 ** @rename ajListSortTwoThree
 */
@@ -806,9 +848,13 @@ __deprecated void ajListSort3(AjPList list,
 			      int (*sort3) (const void*, const void*))
 {
     ajListSortTwoThree(list, sort1, sort2, sort3);
+
     return;
 }
 
+
+
+
 /* @func ajListSortTwoUnique ***************************************************
 **
 ** Double-sort the items in a list, and remove duplicates
@@ -839,9 +885,11 @@ void ajListSortTwoUnique(AjPList list,
     ajListTrace(list);
 
     iter = ajListIterNew(list);
+
     while(!ajListIterDone(iter))
     {
 	item = ajListIterGet(iter);
+
 	if(previtem && !sort1(&item, &previtem) &&
 	   !sort2(&item, &previtem))
 	{
@@ -861,6 +909,8 @@ void ajListSortTwoUnique(AjPList list,
 }
 
 
+
+
 /* @obsolete ajListUnique2
 ** @rename ajListSortTwoUnique
 */
@@ -871,10 +921,13 @@ __deprecated void ajListUnique2(AjPList list,
 				void (*nodedelete) (void** x, void* cl))
 {
     ajListSortTwoUnique(list, sort1, sort2, nodedelete);
+
     return;
 }
 
 
+
+
 /* @func ajListSortUnique ******************************************************
 **
 ** Sort the items in a list, and remove duplicates
@@ -903,9 +956,11 @@ void ajListSortUnique(AjPList list,
     /*ajListTrace(list);*/
 
     iter = ajListIterNew(list);
+
     while(!ajListIterDone(iter))
     {
 	item = ajListIterGet(iter);
+
 	if(previtem && !sort1(&item, &previtem))
 	{
 	    nodedelete(&item, NULL);
@@ -924,6 +979,8 @@ void ajListSortUnique(AjPList list,
 }
 
 
+
+
 /* @obsolete ajListUnique
 ** @rename ajListSortUnique
 */
@@ -933,9 +990,13 @@ __deprecated void ajListUnique(AjPList list,
 		  void (*nodedelete) (void** x, void* cl))
 {
     ajListSortUnique(list, compar, nodedelete);
+
     return;
 }
 
+
+
+
 /* @section Removing data ******************************************************
 **
 ** @fdata [AjPList]
@@ -963,21 +1024,27 @@ __deprecated void ajListUnique(AjPList list,
 static void listFreeSetExpand (void)
 {
     ajint newsize;
+
     if(!listFreeSet)
     {
         listFreeMax = 1024;
         AJCNEW0(listFreeSet,listFreeMax);
+
         return;
     }
+
     if(listFreeMax >= 65536)
         return;
+
     newsize = listFreeMax + listFreeMax;
     AJCRESIZE0(listFreeSet, listFreeMax, newsize);
     listFreeMax = newsize;
+
     return;
 }
 
-    
+
+
     
 /* @func ajListPop ************************************************************
 **
@@ -995,6 +1062,7 @@ AjBool ajListPop(AjPList list, void** x)
     {
         if(x)
             *x = NULL;
+
 	return ajFalse;
     }
     
@@ -1005,8 +1073,8 @@ AjBool ajListPop(AjPList list, void** x)
 	return ajFalse;
 
     list->First->Prev = NULL;
-
     list->Count--;
+
     return ajTrue;
 }
 
@@ -1031,6 +1099,7 @@ AjBool ajListPopLast(AjPList list, void** x)
     {
         if(x)
             *x = NULL;
+
 	return ajFalse;
     }
     
@@ -1047,8 +1116,10 @@ AjBool ajListPopLast(AjPList list, void** x)
     if(list->Count==1)
     {
 	list->Last->Prev = NULL;
+
         if(listFreeNext >= listFreeMax)
             listFreeSetExpand();
+
         if(listFreeNext >= listFreeMax)
             AJFREE(list->First);
         else if(list->First)
@@ -1060,8 +1131,10 @@ AjBool ajListPopLast(AjPList list, void** x)
     {
 	pthis->Prev->Next = list->Last;
 	list->Last->Prev = pthis->Prev;
+
         if(listFreeNext >= listFreeMax)
             listFreeSetExpand();
+
         if(listFreeNext >= listFreeMax)
             AJFREE(pthis);
         else if(pthis)
@@ -1069,10 +1142,7 @@ AjBool ajListPopLast(AjPList list, void** x)
             listFreeSet[listFreeNext++] = pthis;
             pthis = NULL;
         }
-        
     }
-    
-
 
     --list->Count;
 
@@ -1080,6 +1150,8 @@ AjBool ajListPopLast(AjPList list, void** x)
 }
 
 
+
+
 /* @obsolete ajListPopEnd
 ** @rename ajListPopLast
 */
@@ -1089,6 +1161,9 @@ __deprecated AjBool ajListPopEnd(AjPList list, void** x)
     return ajListPopLast(list, x);
 }
 
+
+
+
 /* @section Element retrieval **************************************************
 **
 ** @fdata [AjPList]
@@ -1142,6 +1217,9 @@ ajuint ajListGetLength(const AjPList list)
     return list->Count;
 }
 
+
+
+
 /* @obsolete ajListLength
 ** @rename ajListGetLength
 */
@@ -1153,6 +1231,7 @@ __deprecated ajuint ajListLength(const AjPList list)
 
 
 
+
 /* @func ajListMapfind *****************************************************
 **
 ** For each node in the list call function 'apply' and return
@@ -1181,6 +1260,9 @@ AjBool ajListMapfind(const AjPList list,
     return ajFalse;
 }
 
+
+
+
 /* @obsolete ajListFind
 ** @rename ajListMapfind
 */
@@ -1192,6 +1274,8 @@ __deprecated AjBool ajListFind(const AjPList list,
 }
 
 
+
+
 /* @func ajListMapread ********************************************************
 **
 ** For each node in the list call function apply.
@@ -1217,6 +1301,9 @@ void ajListMapread(const AjPList list,
     return;
 }
 
+
+
+
 /* @obsolete ajListMapRead
 ** @rename ajListMapread
 */
@@ -1229,6 +1316,8 @@ __deprecated void ajListMapRead(const AjPList list,
 }
 
 
+
+
 /* @func ajListPeek ***********************************************************
 **
 ** Return the first node but keep it on the list
@@ -1281,6 +1370,8 @@ AjBool ajListPeekFirst(const AjPList list, void** x)
 }
 
 
+
+
 /* @obsolete ajListFirst
 ** @rename ajListPeekFirst
 */
@@ -1290,6 +1381,9 @@ __deprecated AjBool ajListFirst(const AjPList list, void** x)
     return ajListPeekFirst(list, x);
 }
 
+
+
+
 /* @func ajListPeekLast *******************************************************
 **
 ** Set pointer to last node's data. Does NOT remove the last node.
@@ -1306,6 +1400,7 @@ AjBool ajListPeekLast(const AjPList list, void** x)
 
     if(!list)
 	return ajFalse;
+
     if(!list->Count)
 	return ajFalse;
 
@@ -1319,6 +1414,9 @@ AjBool ajListPeekLast(const AjPList list, void** x)
     return ajTrue;
 }
 
+
+
+
 /* @obsolete ajListLast
 ** @rename ajListPeekLast
 */
@@ -1329,6 +1427,8 @@ __deprecated AjBool ajListLast(const AjPList list, void** x)
 }
 
 
+
+
 /* @func ajListPeekNumber ******************************************************
 **
 ** Set pointer to last node's nth data item. 0 <= n < number of elements.
@@ -1350,6 +1450,7 @@ AjBool ajListPeekNumber(const AjPList list, ajuint ipos, void** x)
 	return ajFalse;
 
     len = ajListGetLength(list);
+
     if(ipos>=len)
 	return ajFalse;
 
@@ -1363,11 +1464,16 @@ AjBool ajListPeekNumber(const AjPList list, ajuint ipos, void** x)
 }
 
 
+
+
 AjBool ajListNth(const AjPList list, ajuint ipos, void** x)
 {
     return ajListPeekNumber(list, ipos, x);
 }
 
+
+
+
 /* @func ajListToarray ********************************************************
 **
 ** Create an array of the pointers to the data.
@@ -1390,6 +1496,7 @@ ajuint ajListToarray(const AjPList list, void*** array)
     if(!n)
     {
 	*array = NULL;
+
 	return 0;
     }
 
@@ -1397,17 +1504,21 @@ ajuint ajListToarray(const AjPList list, void*** array)
 	AJFREE(*array);
 
     *array = AJALLOC((n+1)*sizeof(array));
+
     for(i = 0; i < n; i++)
     {
 	(*array)[i] = rest->Item;
 	rest = rest->Next;
     }
+
     (*array)[n] = 0;
 
     return n;
 }
 
 
+
+
 /* @obsolete ajListToArray
 ** @rename ajListToarray
 */
@@ -1417,6 +1528,9 @@ __deprecated ajuint ajListToArray(const AjPList list, void*** array)
     return ajListToarray(list, array);
 }
 
+
+
+
 /* @funcstatic listArrayTrace *************************************************
 **
 ** Writes debug messages to trace an array generated from a list.
@@ -1548,6 +1662,8 @@ void ajListProbeData(AjPList const * Plist)
 }
 
 
+
+
 /* @func ajListTrace **********************************************************
 **
 ** Traces through a list and validates it
@@ -1622,6 +1738,7 @@ __deprecated AjPListNode ajListNodesNew(void* x, ...)
 	/*ajDebug("topnode: %x node: %x, item: %x -> %x\n",
 		topnode, node, x, node->Next);*/
     }
+
     va_end(ap);
 
     topnode->Prev = NULL;
@@ -1773,8 +1890,10 @@ void ajListFree(AjPList* Plist)
 	for( ; (*rest)->Next; *rest = next)
 	{
 	    next = (*rest)->Next;
+
             if(listFreeNext >= listFreeMax)
                 listFreeSetExpand();
+
             if(listFreeNext >= listFreeMax)
                 AJFREE(*rest);
             else if(*rest)
@@ -1786,6 +1905,7 @@ void ajListFree(AjPList* Plist)
 
     if(listFreeNext >= listFreeMax)
         listFreeSetExpand();
+
     if(listFreeNext >= listFreeMax)
         AJFREE(*rest);
     else if(*rest)
@@ -1842,8 +1962,10 @@ void ajListFreeData(AjPList* Plist)
 	{
 	    AJFREE((*rest)->Item);
 	    next = (*rest)->Next;
+
             if(listFreeNext >= listFreeMax)
                 listFreeSetExpand();
+
             if(listFreeNext >= listFreeMax)
                 AJFREE(*rest);
             else if(*rest)
@@ -1857,6 +1979,7 @@ void ajListFreeData(AjPList* Plist)
 
     if(listFreeNext >= listFreeMax)
         listFreeSetExpand();
+
     if(listFreeNext >= listFreeMax)
         AJFREE(*rest);
     else if(*rest)
@@ -1872,6 +1995,7 @@ void ajListFreeData(AjPList* Plist)
 
 
 
+
 /* @obsolete ajListDel
 ** @rename ajListFree
 */
@@ -1884,6 +2008,7 @@ __deprecated void ajListDel(AjPList* Plist)
 
     if(!Plist)
 	return;
+
     if(!*Plist)
 	return;
 
@@ -1898,8 +2023,10 @@ __deprecated void ajListDel(AjPList* Plist)
 	for( ; (*rest)->Next; *rest = next)
 	{
 	    next = (*rest)->Next;
+
             if(listFreeNext >= listFreeMax)
                 listFreeSetExpand();
+
             if(listFreeNext >= listFreeMax)
                 AJFREE(*rest);
             else if(*rest)
@@ -1911,6 +2038,7 @@ __deprecated void ajListDel(AjPList* Plist)
 
     if(listFreeNext >= listFreeMax)
         listFreeSetExpand();
+
     if(listFreeNext >= listFreeMax)
         AJFREE(*rest);
     else if(*rest)
@@ -1952,6 +2080,7 @@ static AjBool listNodeDel(AjPListNode * pnode)
 
     if(listFreeNext >= listFreeMax)
         listFreeSetExpand();
+
     if(listFreeNext >= listFreeMax)
         AJFREE(*pnode);
     else if(*pnode)
@@ -1964,6 +2093,7 @@ static AjBool listNodeDel(AjPListNode * pnode)
 
 
 
+
 /* @section unused ************************************************************
 **
 ** @fdata [AjPList]
@@ -2115,6 +2245,9 @@ AjIList ajListIterNew(AjPList list)
     return iter;
 }
 
+
+
+
 /* @obsolete ajListIter
 ** @rename ajListIterNew
 */
@@ -2124,6 +2257,9 @@ __deprecated AjIList ajListIter(AjPList list)
     return ajListIterNew(list);
 }
 
+
+
+
 /* @func ajListIterNewBack *****************************************************
 **
 ** Creates an iterator to operate from end to start of the list.
@@ -2148,6 +2284,7 @@ AjIList ajListIterNewBack(AjPList list)
 
     for(node=list->First; node->Next; node = node->Next)
 	tmp = node;
+
     list->Last->Prev = tmp;
 
     AJNEW0(iter);
@@ -2164,6 +2301,8 @@ AjIList ajListIterNewBack(AjPList list)
 }
 
 
+
+
 /* @obsolete ajListIterBack
 ** @rename ajListIterNewBack
 */
@@ -2173,6 +2312,9 @@ __deprecated AjIList ajListIterBack(AjPList list)
     return ajListIterNewBack(list);
 }
 
+
+
+
 /* @func ajListIterNewread *****************************************************
 **
 ** Creates an iterator to operate from start to end of list.
@@ -2204,6 +2346,9 @@ AjIList ajListIterNewread(const AjPList list)
     return iter;
 }
 
+
+
+
 /* @obsolete ajListIterRead
 ** @rename ajListIterNewread
 */
@@ -2214,6 +2359,8 @@ __deprecated AjIList ajListIterRead(const AjPList list)
 }
 
 
+
+
 /* @func ajListIterNewreadBack *************************************************
 **
 ** Creates an iterator to operate from end to start of the list.
@@ -2237,6 +2384,7 @@ AjIList ajListIterNewreadBack(const AjPList list)
 
     for(node=list->First; node->Next; node = node->Next)
 	tmp = node;
+
     list->Last->Prev = tmp;
 
     AJNEW0(iter);
@@ -2252,6 +2400,9 @@ AjIList ajListIterNewreadBack(const AjPList list)
     return iter;
 }
 
+
+
+
 /* @obsolete ajListIterBackRead
 ** @rename ajListIterNewreadBack
 */
@@ -2261,6 +2412,9 @@ __deprecated AjIList ajListIterBackRead(const AjPList list)
     return ajListIterNewreadBack(list);
 }
 
+
+
+
 /* @section tests *************************************************************
 ** @fdata [AjIList]
 ** @nam4rule   Done      Check whether iteration has ended (no more
@@ -2306,6 +2460,7 @@ AjBool ajListIterDone(const AjIList iter)
 
 
 
+
 /* @obsolete ajListIterMore
 ** @remove use ajListIterDone
 */
@@ -2316,6 +2471,8 @@ __deprecated AjBool ajListIterMore(const AjIList iter)
 }
 
 
+
+
 /* @obsolete ajListIterMoreBack
 ** @remove use ajListIterDoneBack
 */
@@ -2353,6 +2510,8 @@ AjBool ajListIterDoneBack(const AjIList iter)
 }
 
 
+
+
 /* @obsolete ajListIterBackDone
 ** @rename ajListIterDoneBack
 */
@@ -2364,6 +2523,7 @@ __deprecated AjBool ajListIterBackDone(const AjIList iter)
 
 
 
+
 /* @section destructors *******************************************************
 ** @fdata [AjIList]
 **
@@ -2398,6 +2558,9 @@ void ajListIterDel(AjIList* iter)
     return;
 }
 
+
+
+
 /* @obsolete ajListIterFree
 ** @rename ajListIterDel
 */
@@ -2409,6 +2572,8 @@ __deprecated void ajListIterFree(AjIList* iter)
 }
 
 
+
+
 /* @obsolete ajListIterBackMore
 ** @remove use ajListIterDoneBack
 */
@@ -2419,6 +2584,8 @@ __deprecated AjBool ajListIterBackMore(const AjIList iter)
 }
 
 
+
+
 /* @section stepping **********************************************************
 **
 ** @fdata [AjIList]
@@ -2457,6 +2624,7 @@ void* ajListIterGet(AjIList iter)
     {
 	if(!p->Next)
 	    return NULL;
+
 	ret = p->Item;
 	iter->Here = p->Next;
     }
@@ -2464,6 +2632,7 @@ void* ajListIterGet(AjIList iter)
     {
 	if(!p->Next->Next || !p->Next->Next->Next)
 	  return NULL;
+
 	iter->Back = ajFalse;
 	ret = p->Next->Item;
 	iter->Here = p->Next->Next;
@@ -2473,6 +2642,8 @@ void* ajListIterGet(AjIList iter)
 }
 
 
+
+
 /* @obsolete ajListIterNext
 ** @rename ajListIterGet
 */
@@ -2482,6 +2653,9 @@ __deprecated void* ajListIterNext(AjIList iter)
     return ajListIterGet(iter);
 }
 
+
+
+
 /* @func ajListIterGetBack *************************************************
 **
 ** Returns next item using back iterator.
@@ -2504,11 +2678,11 @@ void* ajListIterGetBack(AjIList iter)
     if(!p->Prev)
       return NULL;
 
-    if(!iter->Back)
+    if(!iter->Back && p->Prev->Prev)
     {
-	ret = p->Prev->Prev->Item;
-	iter->Here = p->Prev->Prev;
-	iter->Back = ajTrue;
+        ret = p->Prev->Prev->Item;
+        iter->Here = p->Prev->Prev;
+        iter->Back = ajTrue;
     }
     else
     {
@@ -2520,6 +2694,8 @@ void* ajListIterGetBack(AjIList iter)
 }
 
 
+
+
 /* @obsolete ajListIterBackNext
 ** @rename ajListIterGetBack
 */
@@ -2529,6 +2705,9 @@ __deprecated void* ajListIterBackNext(AjIList iter)
     return ajListIterGetBack(iter);
 }
 
+
+
+
 /* @section modifiers **********************************************************
 **
 ** @fdata [AjIList]
@@ -2579,6 +2758,7 @@ void ajListIterInsert(AjIList iter, void* x)
 	    listInsertNode(&list->First,x);
 	else
 	    listInsertNode(&p->Prev->Next,x);
+
 	iter->Here = p->Prev;
     }
     else
@@ -2606,6 +2786,7 @@ void ajListIterInsert(AjIList iter, void* x)
 
 
 
+
 /* @obsolete ajListInsert
 ** @rename ajListIterInsert
 */
@@ -2617,6 +2798,8 @@ __deprecated void ajListInsert(AjIList iter, void* x)
 }
 
 
+
+
 /* @func ajListIterRemove *****************************************************
 **
 ** Remove an item from a list, using an iterator (if not null)
@@ -2676,6 +2859,9 @@ __deprecated void ajListRemove(AjIList iter)
     return;
 }
 
+
+
+
 /* @func ajListIterRewind ******************************************************
 **
 ** Resets iterator to start position
@@ -2703,6 +2889,7 @@ void ajListIterRewind(AjIList iter)
     {
         for(node=list->First; node->Next; node = node->Next)
             tmp = node;
+
         iter->Here = tmp->Next;
     }
     else
@@ -2714,6 +2901,8 @@ void ajListIterRewind(AjIList iter)
 }
 
 
+
+
 /* @section Trace functions ***************************************************
 **
 ** @fdata [AjIList]
@@ -2743,7 +2932,8 @@ void ajListIterTrace(const AjIList iter)
 {
     ajuint icount = 0;
 
-    if(!iter) {
+    if(!iter)
+    {
 	ajDebug("\nIterator NULL\n");
 	return;
     }
@@ -2805,6 +2995,7 @@ AjPList ajListstrNew(void)
 
 
 
+
 /* @func ajListstrNewList ******************************************************
 **
 ** Copy a list, with copies of all the string values.
@@ -2841,6 +3032,7 @@ AjPList ajListstrNewList(const AjPList list)
 
 
 
+
 /* @obsolete ajListstrClone
 ** @remove use ajListstrNewList
 */
@@ -2889,6 +3081,8 @@ AjPList ajListstrNewListref(const AjPList list)
 }
 
 
+
+
 /* @obsolete ajListstrCopy
 ** @rename ajListstrNewList
 */
@@ -2898,6 +3092,9 @@ __deprecated AjPList ajListstrCopy(const AjPList list)
     return ajListstrNewListref(list);
 }
 
+
+
+
 /* @section Adding values ******************************************************
 **
 ** @fdata [AjPList]
@@ -2953,6 +3150,9 @@ void ajListstrPushAppend(AjPList list, AjPStr x)
     return;
 }
 
+
+
+
 /* @obsolete ajListstrPushApp
 ** @rename ajListstrPushAppend
 */
@@ -2961,10 +3161,13 @@ __deprecated void ajListstrPushApp(AjPList list, AjPStr x)
 {
 
     ajListstrPushAppend(list, x);
+
     return;
 }
 
 
+
+
 /* @func ajListstrPushlist ****************************************************
 **
 ** Adds a list to the start of the current list, then deletes the second list.
@@ -2983,6 +3186,8 @@ void ajListstrPushlist(AjPList list, AjPList* Plist)
 }
 
 
+
+
 /* @obsolete ajListstrPushList
 ** @rename ajListstrPushlist
 */
@@ -2990,9 +3195,13 @@ void ajListstrPushlist(AjPList list, AjPList* Plist)
 __deprecated void ajListstrPushList(AjPList list, AjPList* Plist)
 {
     ajListstrPushlist(list, Plist);
+
     return;
 }
 
+
+
+
 /* @section Modifiers **********************************************************
 **
 ** @fdata [AjPList]
@@ -3033,7 +3242,6 @@ void ajListstrMap(AjPList list, void apply(AjPStr* x, void* cl), void* cl)
     for(rest=list->First; rest->Next; rest = rest->Next)
 	apply((AjPStr*) &rest->Item, cl);
 
-
     return;
 }
 
@@ -3058,6 +3266,7 @@ void ajListstrReverse(AjPList list)
 
 
 
+
 /* @section Removing data ******************************************************
 **
 ** @fdata [AjPList]
@@ -3098,8 +3307,8 @@ AjBool ajListstrPop(AjPList list, AjPStr* Pstr)
 	return ajFalse;
 
     list->First->Prev = NULL;
-
     list->Count--;
+
     return ajTrue;
 }
 
@@ -3135,8 +3344,10 @@ AjBool ajListstrPopLast(AjPList list, AjPStr *Pstr)
     if(list->Count==1)
     {
 	list->Last->Prev = NULL;
+
         if(listFreeNext >= listFreeMax)
             listFreeSetExpand();
+
         if(listFreeNext >= listFreeMax)
             AJFREE(list->First);
         else if(list->First)
@@ -3148,8 +3359,10 @@ AjBool ajListstrPopLast(AjPList list, AjPStr *Pstr)
     {
 	pthis->Prev->Next = list->Last;
 	list->Last->Prev = pthis->Prev;
+
         if(listFreeNext >= listFreeMax)
             listFreeSetExpand();
+
         if(listFreeNext >= listFreeMax)
             AJFREE(pthis);
         else if(pthis)
@@ -3159,14 +3372,13 @@ AjBool ajListstrPopLast(AjPList list, AjPStr *Pstr)
         }
     }
 
-    
-
-
     --list->Count;
     return ajTrue;
 }
 
 
+
+
 /* @obsolete ajListstrPopEnd
 ** @rename ajListstrPopLast
 */
@@ -3177,6 +3389,8 @@ __deprecated AjBool ajListstrPopEnd(AjPList list, AjPStr *x)
 }
 
 
+
+
 /* @section Element retrieval **************************************************
 **
 ** @fdata [AjPList]
@@ -3229,6 +3443,8 @@ ajuint ajListstrGetLength(const AjPList list)
 }
 
 
+
+
 /* @obsolete ajListstrLength
 ** @rename ajListstrGetLength
 */
@@ -3239,6 +3455,8 @@ __deprecated ajuint ajListstrLength(const AjPList list)
 }
 
 
+
+
 /* @func ajListstrMapfind **************************************************
 **
 ** For each node in the list call function apply and return
@@ -3269,6 +3487,8 @@ AjBool ajListstrMapfind(const AjPList list,
 }
 
 
+
+
 /* @obsolete ajListstrFind
 ** @rename ajListstrMapfind
 */
@@ -3280,6 +3500,9 @@ __deprecated AjBool ajListstrFind(const AjPList list,
     return ajListstrMapfind(list, apply, cl);
 }
 
+
+
+
 /* @func ajListstrMapread *****************************************************
 **
 ** For each node in the list call function apply,
@@ -3307,6 +3530,9 @@ void ajListstrMapread(const AjPList list,
     return;
 }
 
+
+
+
 /* @obsolete ajListstrMapRead
 ** @rename ajListstrMapread
 */
@@ -3316,9 +3542,13 @@ __deprecated void ajListstrMapRead(const AjPList list,
 {
 
     ajListstrMapread(list, apply, cl);
+
     return;
 }
 
+
+
+
 /* @func ajListstrPeek ********************************************************
 **
 ** Return the first node but keep it on the list.
@@ -3369,6 +3599,7 @@ ajuint ajListstrToarray(const AjPList list, AjPStr** array)
     if(!n)
     {
 	*array = NULL;
+
 	return 0;
     }
 
@@ -3379,12 +3610,15 @@ ajuint ajListstrToarray(const AjPList list, AjPStr** array)
 	(*array)[i] = (AjPStr) rest->Item;
 	rest = rest->Next;
     }
+
     (*array)[n] = 0;
 
     return n;
 }
 
 
+
+
 /* @obsolete ajListstrToArray
 ** @rename ajListstrToarray
 */
@@ -3394,6 +3628,9 @@ __deprecated ajuint ajListstrToArray(const AjPList list, AjPStr** array)
     return ajListstrToarray(list, array);
 }
 
+
+
+
 /* @func ajListstrToarrayAppend ************************************************
 **
 ** append to an array of the pointers to the data.
@@ -3428,6 +3665,7 @@ ajuint ajListstrToarrayAppend(const AjPList list, AjPStr** array)
     if(!n)
     {
 	*array = NULL;
+
 	return 0;
     }
 
@@ -3438,12 +3676,15 @@ ajuint ajListstrToarrayAppend(const AjPList list, AjPStr** array)
 	(*array)[i] = (AjPStr) rest->Item;
 	rest = rest->Next;
     }
+
     (*array)[n] = 0;
 
     return n;
 }
 
 
+
+
 /* @obsolete ajListstrToArrayApp
 ** @rename ajListstrToarrayAppend
 */
@@ -3453,6 +3694,9 @@ __deprecated ajuint ajListstrToArrayApp(const AjPList list, AjPStr** array)
     return ajListstrToarrayAppend(list, array);
 }
 
+
+
+
 /* @section Trace functions ***************************************************
 **
 ** @fdata [AjPList]
@@ -3520,6 +3764,7 @@ void ajListstrTrace(const AjPList list)
 
 
 
+
 /* @obsolete ajListstrNewArgs
 ** @remove Use ajListstrNew and ajListPush
 */
@@ -3547,6 +3792,8 @@ __deprecated AjPList ajListstrNewArgs(AjPStr x, ...)
 }
 
 
+
+
 /* @section Destructors *******************************************************
 **
 ** @fdata [AjPList]
@@ -3586,6 +3833,8 @@ void ajListstrFree(AjPList* Plist)
 }
 
 
+
+
 /* @obsolete ajListstrDel
 ** @rename ajListstrFree
 */
@@ -3593,9 +3842,13 @@ void ajListstrFree(AjPList* Plist)
 __deprecated void ajListstrDel(AjPList* pthis)
 {
     ajListstrFree(pthis);
+
     return;
 }
 
+
+
+
 /* @func ajListstrFreeData *****************************************************
 **
 ** Free all nodes in a string list.
@@ -3633,8 +3886,10 @@ void ajListstrFreeData(AjPList* Plist)
 	{
 	    next = (*rest)->Next;
 	    ajStrDel((AjPStr*) &(*rest)->Item);
+
             if(listFreeNext >= listFreeMax)
                 listFreeSetExpand();
+
             if(listFreeNext >= listFreeMax)
                 AJFREE(*rest);
             else if(*rest)
@@ -3643,12 +3898,14 @@ void ajListstrFreeData(AjPList* Plist)
                 *rest=NULL;
             }
 	}
+
 	ajStrDel((AjPStr*) &(*rest)->Item);
     }
 
 
     if(listFreeNext >= listFreeMax)
         listFreeSetExpand();
+
     if(listFreeNext >= listFreeMax)
         AJFREE(*rest);
     else if(*rest)
@@ -3716,6 +3973,7 @@ AjPStr ajListstrIterGet(AjIList iter)
     {
 	if(!p->Next)
 	    return NULL;
+
 	ret = p->Item;
 	iter->Here = p->Next;
     }
@@ -3723,6 +3981,7 @@ AjPStr ajListstrIterGet(AjIList iter)
     {
 	if(!p->Next->Next || !p->Next->Next->Next)
 	  return NULL;
+
 	iter->Back = ajFalse;
 	ret = p->Next->Item;
 	iter->Here = p->Next->Next;
@@ -3731,6 +3990,9 @@ AjPStr ajListstrIterGet(AjIList iter)
     return (AjPStr) ret;
 }
 
+
+
+
 /* @func ajListstrIterGetBack *************************************************
 **
 ** Returns next item using back iterator.
@@ -3769,6 +4031,8 @@ AjPStr ajListstrIterGetBack(AjIList iter)
 }
 
 
+
+
 /* @section modifiers **********************************************************
 **
 ** @fdata [AjIList]
@@ -3851,6 +4115,7 @@ void ajListstrIterInsert(AjIList iter, AjPStr str)
 
 
 
+
 /* @obsolete ajListstrInsert
 ** @rename ajListstrIterInsert
 */
@@ -3858,9 +4123,13 @@ void ajListstrIterInsert(AjIList iter, AjPStr str)
 __deprecated void ajListstrInsert(AjIList iter, AjPStr str)
 {
     ajListstrIterInsert(iter, str);
+
     return;
 }
 
+
+
+
 /* @func ajListstrIterRemove **************************************************
 **
 ** Remove an item from a list, using an iterator (if not null)
@@ -3909,14 +4178,14 @@ void ajListstrIterRemove(AjIList iter)
 	listNodeDel(&p->Prev->Prev->Next);
     }
 
-
-
     iter->Head->Count--;
 
     return;
 }
 
 
+
+
 /* @obsolete ajListstrRemove
 ** @rename ajListstrIterRemove
 */
@@ -3924,10 +4193,13 @@ void ajListstrIterRemove(AjIList iter)
 __deprecated void ajListstrRemove(AjIList iter)
 {
     ajListstrIterRemove(iter);
+
     return;
 }
 
 
+
+
 /* @section Trace functions ***************************************************
 **
 ** @fdata [AjIList]
