@@ -125,6 +125,7 @@ AjPRange ajRangeCopy(const AjPRange src)
 	thys->start = AJALLOC0(n*sizeof(ajuint));
 	thys->end   = AJALLOC0(n*sizeof(ajuint));
 	thys->text  = AJALLOC0(n*sizeof(AjPStr *));
+
 	for(i=0; i < n; i++)
 	{
 	    thys->start[i] = src->start[i];
@@ -169,6 +170,7 @@ void ajRangeDel(AjPRange *thys)
     {
 	AJFREE((*thys)->start);
 	AJFREE((*thys)->end);
+
 	for(i=0; i < (*thys)->n; i++)
 	    ajStrDel(&(*thys)->text[i]);
     }
@@ -282,6 +284,7 @@ AjPRange ajRangeGetLimits(const AjPStr str, ajuint imin, ajuint imax,
 	    if(n%2)
 	    {
 		ajWarn("Odd integer(s) in range specification [%d]",n);
+
 		return NULL;
 	    }
 
@@ -291,6 +294,7 @@ AjPRange ajRangeGetLimits(const AjPStr str, ajuint imin, ajuint imax,
 		{
 		    ajWarn("Range specification requires exactly %d pairs",
 			   size);
+
 		    return NULL;
 		}
 	    }
@@ -298,6 +302,7 @@ AjPRange ajRangeGetLimits(const AjPStr str, ajuint imin, ajuint imax,
 	    {
 		ajWarn("Range specification requires at least %d pairs",
 		       minsize);
+
 		return NULL;
 	    }
 	    ret=ajRangeNewI((e=n>>1));
@@ -305,18 +310,22 @@ AjPRange ajRangeGetLimits(const AjPStr str, ajuint imin, ajuint imax,
 	    /* get the pairs of numbers and put them in the AjPRange object */
 	    cp = ajStrGetPtr(c2);
 	    p = ajSysFuncStrtok(cp, nondigit);
+
 	    if(!sscanf(p,"%d",&f))
 	    {
 		ajWarn("Bad range value [%s]",p);
 		ajRangeDel(&ret);
+
 		return NULL;
 	    }
 
 	    p = ajSysFuncStrtok(NULL, nondigit);
+
 	    if(!sscanf(p,"%d",&t))
 	    {
 		ajWarn("Bad range value [%s]",p);
 		ajRangeDel(&ret);
+
 		return NULL;
 	    }
 
@@ -324,6 +333,7 @@ AjPRange ajRangeGetLimits(const AjPStr str, ajuint imin, ajuint imax,
 	    {
 		ajWarn("From range [%d] greater than To range [%d]",f,t);
 		ajRangeDel(&ret);
+
 		return NULL;
 	    }
 
@@ -331,6 +341,7 @@ AjPRange ajRangeGetLimits(const AjPStr str, ajuint imin, ajuint imax,
 	    {
 		ajWarn("From range [%d] less than minimum [%d]",f,imin);
 		ajRangeDel(&ret);
+
 		return NULL;
 	    }
 
@@ -338,6 +349,7 @@ AjPRange ajRangeGetLimits(const AjPStr str, ajuint imin, ajuint imax,
 	    {
 		ajWarn("To range [%d] greater than maximum [%d]",t,imax);
 		ajRangeDel(&ret);
+
 		return NULL;
 	    }
 
@@ -347,18 +359,22 @@ AjPRange ajRangeGetLimits(const AjPStr str, ajuint imin, ajuint imax,
 	    for(i=1;i<e;++i)
 	    {
 		p = ajSysFuncStrtok(NULL, nondigit);
+
 		if(!sscanf(p,"%d",&f))
 		{
 		    ajWarn("Bad range value [%s]",p);
 		    ajRangeDel(&ret);
+
 		    return NULL;
 		}
 
 		p = ajSysFuncStrtok(NULL, nondigit);
+
 		if(!sscanf(p,"%d",&t))
 		{
 		    ajWarn("Bad range value [%s]",p);
 		    ajRangeDel(&ret);
+
 		    return NULL;
 		}
 
@@ -366,14 +382,17 @@ AjPRange ajRangeGetLimits(const AjPStr str, ajuint imin, ajuint imax,
 		{
 		    ajWarn("From range [%d] greater than To range [%d]",f,t);
 		    ajRangeDel(&ret);
+
 		    return NULL;
 		}
+
 		ret->start[i] = f;
 		ret->end[i]   = t;
 	    }
 
 	    /* now get any strings after the pairs of ranges */
 	    cp = ajStrGetPtr(c3);
+
 	    if(!isdigit((ajint)*cp))
 	    {
 		doneone = ajTrue;
@@ -394,6 +413,7 @@ AjPRange ajRangeGetLimits(const AjPStr str, ajuint imin, ajuint imax,
 		/* this must be the text after the pair of numbers */
 		/* get the string after the two numbers */
 		p = ajSysFuncStrtok(NULL, digit);
+
 		if(p)
 		{
 		    ajStrAssignC(&(ret->text[i]), p);
@@ -407,12 +427,14 @@ AjPRange ajRangeGetLimits(const AjPStr str, ajuint imin, ajuint imax,
 	    {
 		ajWarn("Range specification requires exactly %d pairs",
 		       size);
+
 		return NULL;
 	    }
 	    else if (0 < minsize)
 	    {
 		ajWarn("Range specification requires at least %d pairs",
 		       minsize);
+
 		return NULL;
 	    }
 	    ret=ajRangeNewI(0);
@@ -463,6 +485,9 @@ AjPRange ajRangeFile(const AjPStr name)
     return ajRangeFileLimits(name, 1, UINT_MAX, 0, 0);
 }
 
+
+
+
 /* @func ajRangeFileLimits ****************************************************
 **
 ** Load a range object from a file
@@ -531,6 +556,7 @@ AjPRange ajRangeFileLimits(const AjPStr name, ajuint imin, ajuint imax,
 	
 	if(!ajStrFindC(line, "#"))
 	    continue;
+
 	if(!ajStrGetLen(line))
 	    continue;
 	
@@ -550,11 +576,13 @@ AjPRange ajRangeFileLimits(const AjPStr name, ajuint imin, ajuint imax,
 	
 	two = ajStrNew();
 	ajStrTokenNextParse(&tokens, &two);
+
 	if(ajStrGetLen(two))
 	    ajListstrPushAppend(twolist, two);
 	else
 	{
 	    ajWarn("Odd integer(s) in range specification:\n%S\n", line);
+
 	    return NULL;
 	}
 	
@@ -575,6 +603,7 @@ AjPRange ajRangeFileLimits(const AjPStr name, ajuint imin, ajuint imax,
 	{
 	    ajWarn("Range specification requires exactly %d pairs",
 		   size);
+
 	    return NULL;
 	}
     }
@@ -582,8 +611,10 @@ AjPRange ajRangeFileLimits(const AjPStr name, ajuint imin, ajuint imax,
     {
 	ajWarn("Range specification requires at least %d pairs",
 	       minsize);
+
 	return NULL;
     }
+
     ret = ajRangeNewI(n);
 
 
@@ -595,6 +626,7 @@ AjPRange ajRangeFileLimits(const AjPStr name, ajuint imin, ajuint imax,
 	{
 	    ajWarn("Bad range value [%S]",one);
 	    ajRangeDel(&ret);
+
 	    return NULL;
 	}
 	
@@ -603,6 +635,7 @@ AjPRange ajRangeFileLimits(const AjPStr name, ajuint imin, ajuint imax,
 	{
 	    ajWarn("Bad range value [%S]",two);
 	    ajRangeDel(&ret);
+
 	    return NULL;
 	}
 
@@ -614,6 +647,7 @@ AjPRange ajRangeFileLimits(const AjPStr name, ajuint imin, ajuint imax,
 	    ajWarn("From range [%d] greater than To range [%d]",
 		   numone, numtwo);
 	    ajRangeDel(&ret);
+
 	    return NULL;
 	}
 
@@ -622,6 +656,7 @@ AjPRange ajRangeFileLimits(const AjPStr name, ajuint imin, ajuint imax,
 	    ajWarn("From range [%d] less than minimum [%d]",
 		   numone,imin);
 	    ajRangeDel(&ret);
+
 	    return NULL;
 	}
 
@@ -630,6 +665,7 @@ AjPRange ajRangeFileLimits(const AjPStr name, ajuint imin, ajuint imax,
 	    ajWarn("To range [%d] greater than maximum [%d]",
 		   numtwo,imax);
 	    ajRangeDel(&ret);
+
 	    return NULL;
 	}
 
@@ -691,10 +727,13 @@ AjBool ajRangeValues(const AjPRange thys, ajuint element,
 {
     if(element>=thys->n)
 	return ajFalse;
+
     if(thys->start[element] < 1)
 	return ajFalse;
+
     if(thys->end[element] < 1)
 	return ajFalse;
+
     if(thys->start[element] > thys->end[element])
 	return ajFalse;
 
@@ -800,6 +839,7 @@ AjBool ajRangeBegin(AjPRange thys, ajuint begin)
     {
 	if(begin > 1)
 	    result = ajTrue;
+
 	ajRangeValues(thys, i, &st, &en);
 	st -= begin-1;
 	en -= begin-1;
@@ -811,6 +851,7 @@ AjBool ajRangeBegin(AjPRange thys, ajuint begin)
 
 
 
+
 /* @func ajRangeSeqExtractList ************************************************
 **
 ** Extract the range from a sequence and place the resulting text in a
@@ -847,8 +888,10 @@ AjBool ajRangeSeqExtractList(const AjPRange thys,
 	for(i=0; i<nr; i++)
 	{
 	    result = ajTrue;
+
 	    if(!ajRangeValues(thys,i,&st,&en))
 		continue;
+
 	    str = ajStrNew();
 	    ajStrAppendSubS(&str, ajSeqGetSeqS(seq), st-1, en-1);
 	    ajListstrPushAppend(outliststr, str);
@@ -899,8 +942,10 @@ AjBool ajRangeSeqExtract(const AjPRange thys, AjPSeq seq)
 	for(i=0; i<nr; i++)
 	{
 	    result = ajTrue;
+
 	    if(!ajRangeValues(thys,i,&st,&en))
 	       continue;
+
 	    ajStrAppendSubS(&outstr, ajSeqGetSeqS(seq), st-1, en-1);
 	    ajDebug("Range [%d] %d..%d '%S'\n", i, st, en, outstr);
 	}
@@ -914,10 +959,137 @@ AjBool ajRangeSeqExtract(const AjPRange thys, AjPSeq seq)
 
 
 
+/* @func ajRangeSeqExtractPep ***********************************************
+**
+** Extract the range from a sequence (Remove regions not in the range(s))
+** and translate to protein.
+**
+** N.B. the resulting sequence will be regions of the original concatenated
+** in the order specified in the set of ranges. If these are not in ascending
+** order, the resulting sequence will not be in position order either.
+**
+** @param [r] thys [const AjPRange] range object
+** @param [u] seq [AjPSeq] Sequence
+** @param [r] trntable [const AjPTrn] Translation table
+** @param [r] frame [ajint] Reading frame 1..3 or -1..-3
+**
+** @return [AjPSeq] Translated protein sequence
+** @category use [AjPRange] Extract substrings defined by range
+** @@
+******************************************************************************/
+
+AjPSeq ajRangeSeqExtractPep(const AjPRange thys, AjPSeq seq,
+                            const AjPTrn trntable, ajint frame)
+{
+    ajuint nr;
+    ajuint i;
+    ajuint st;
+    ajuint en;
+    AjPStr outstr = NULL;
+    AjPSeq pepseq = NULL;
+    AjPStr pepstr = NULL;
+    ajuint pos = 0;
+    ajuint lastpos = 0;
+    ajuint npos = 0;
+    ajuint rlen = 0;
+    ajuint shift = 0;
+
+    nr = ajRangeNumber(thys);
+
+    if (!nr)
+        return NULL;
+
+    if(frame > 0)
+    {
+	for(i=0; i<nr; i++)
+	{
+	    if(!ajRangeValues(thys,i,&st,&en))
+	       continue;
+
+            ajStrAppendSubS(&outstr, ajSeqGetSeqS(seq), st-1, en-1);
+	}
+
+	ajSeqAssignSeqS(seq, outstr);
+	ajStrAssignClear(&outstr);
+        pepseq = ajTrnSeqOrig(trntable, seq, 1);
+        ajStrAssignS(&pepstr, ajSeqGetSeqS(pepseq));
+
+	for(i=0; i<nr; i++)
+	{
+	    if(!ajRangeValues(thys,i,&st,&en))
+	       continue;
+
+            shift = npos%3;
+
+            rlen = (en-st)+1;
+            npos += rlen;
+            pos = (npos-1)/3;
+
+            if(frame%3 == (((ajint)st-(ajint)shift) % 3))
+            {
+                if(pos >= lastpos)
+                    ajStrAppendSubS(&outstr, pepstr, lastpos, pos);
+            }
+
+            if(pos >= lastpos)
+                lastpos = pos+1;
+            else
+                lastpos = pos;
+	}
+
+	ajSeqAssignSeqS(pepseq, outstr);
+	ajStrDel(&pepstr);
+	ajStrDel(&outstr);
+    }
+    else if (frame < 0)
+    {
+	for(i=nr; i>0; i--)
+	{
+	    if(!ajRangeValues(thys,i-1, &st,&en))
+	       continue;
+
+            ajStrAppendSubS(&outstr, ajSeqGetSeqS(seq), st-1, en-1);
+	}
+
+	ajSeqAssignSeqS(seq, outstr);
+	ajStrAssignClear(&outstr);
+        pepseq = ajTrnSeqOrig(trntable, seq, -1);
+        ajStrAssignS(&pepstr, ajSeqGetSeqS(pepseq));
+
+	for(i=0; i<nr; i++)
+	{
+	    if(!ajRangeValues(thys,i, &st,&en))
+	       continue;
+
+            rlen = (en-st)+1;
+            npos += rlen;
+            pos = (npos-1)/3;
+
+            if((-frame)%3 == (((ajint)st) % 3))
+            {
+                if(pos >= lastpos)
+                    ajStrAppendSubS(&outstr, pepstr, lastpos, pos);
+            }
+
+            if(pos >= lastpos)
+                lastpos = pos+1;
+            else
+                lastpos = pos;
+	}
+
+	ajSeqAssignSeqS(pepseq, outstr);
+	ajStrDel(&outstr);
+    }
+    
+    return pepseq;
+}
+
+
+
 
 /* @func ajRangeSeqStuff ******************************************************
 **
-** The opposite of ajRangeStrExtract()
+** The opposite of ajRangeSeqExtract()
 ** Stuff space characters into a string to pad out to the range.
 **
 ** It takes a string and an ordered, non-overlapping set of ranges and puts
@@ -953,6 +1125,7 @@ AjBool ajRangeSeqStuff(const AjPRange thys, AjPSeq seq)
 	for(i=0; i<nr; i++)
 	{
 	    result = ajTrue;
+
 	    if(!ajRangeValues(thys,i,&st,&en))
 		continue;
 
@@ -968,6 +1141,7 @@ AjBool ajRangeSeqStuff(const AjPRange thys, AjPSeq seq)
 	    lastst = lastst+len+1;
 	    lasten = en+1;
 	}
+
 	ajSeqAssignSeqS(seq, outstr);
 	ajStrDel(&outstr);
     }
@@ -978,6 +1152,121 @@ AjBool ajRangeSeqStuff(const AjPRange thys, AjPSeq seq)
 
 
 
+/* @func ajRangeSeqStuffPep *************************************************
+**
+** The opposite of ajRangeSeqExtractPep()
+** Stuff space characters into a translated string to pad out to the range.
+**
+** It takes a string and an ordered, non-overlapping set of ranges and puts
+** spaces into the string between the ranges.
+** So starting with the string 'abcde' and the ranges 3-5,7-8 it will produce:
+** '  abc de'
+**
+** @param [r] thys [const AjPRange] range object
+** @param [u] seq [AjPSeq] Sequence to be modified
+** @param [r] frame [ajint] Reading frame 1..3 or -1..-3
+**
+** @return [AjBool] true if sequence was modified
+** @category use [AjPRange] The opposite of ajRangeSeqExtract
+** @@
+******************************************************************************/
+
+AjBool ajRangeSeqStuffPep(const AjPRange thys, AjPSeq seq, ajint frame)
+{
+    ajuint nr;
+    ajuint i;
+    ajuint j;
+    ajuint lasten = 0;
+    ajuint lastst = 0;
+    ajuint len;
+    ajuint st;
+    ajuint en;
+    ajuint nbases = 0;
+    ajuint shift = 0;
+    AjBool result = ajFalse;
+    AjPStr outstr = NULL;
+    ajint lastframe = 0;
+
+    nr = ajRangeNumber(thys);
+
+    if(!nr)
+        return ajFalse;
+
+    if(frame > 0)
+    {
+	for(i=0; i<nr; i++)
+	{
+	    result = ajTrue;
+
+	    if(!ajRangeValues(thys,i,&st,&en))
+		continue;
+
+            shift = nbases%3;
+            nbases += en-st+1;
+
+            if((frame)%3 != (((ajint)st-(ajint)shift) % 3))
+                continue;
+
+	    /* change range positions to string positions */
+	    --st;
+	    --en;
+	    len = en-st;
+
+            ajDebug("lasten:%u st:%u shift:%u frame:%d lastframe:%d\n",
+                   lasten, st, shift, frame, lastframe);
+	    for(j=lasten; j<st; j++)
+		ajStrAppendC(&outstr, " ");
+
+            if(shift && (frame != lastframe))
+                for(j=3; j>shift; j--)
+                    ajStrAppendC(&outstr, " ");
+
+	    ajStrAppendSubS(&outstr, ajSeqGetSeqS(seq), lastst, lastst+len);
+	    lastst = lastst+len+1;
+	    lasten = en+1;
+            lastframe = frame;
+	}
+
+	ajSeqAssignSeqS(seq, outstr);
+	ajStrDel(&outstr);
+    }
+    else if (frame < 0)
+    {
+        ajSeqReverseOnly(seq);
+
+	for(i=nr; i>0; i--)
+	{
+	    result = ajTrue;
+	    if(!ajRangeValues(thys,i-1,&st,&en))
+		continue;
+
+            if((-frame)%3 != (((ajint)st) % 3))
+                continue;
+
+	    /* change range positions to string positions */
+	    --st;
+	    --en;
+	    len = en-st;
+
+	    for(j=lasten; j<st; j++)
+		ajStrAppendC(&outstr, " ");
+
+	    ajStrAppendSubS(&outstr, ajSeqGetSeqS(seq), lastst, lastst+len);
+	    lastst = lastst+len+1;
+	    lasten = en+1;
+	}
+
+	ajSeqAssignSeqS(seq, outstr);
+	ajStrDel(&outstr);
+    }
+    
+
+    return result;
+}
+
+
+
+
 /* @func ajRangeSeqMask *******************************************************
 **
 ** Mask the range in a String
@@ -1029,8 +1318,10 @@ AjBool ajRangeSeqMask(const AjPRange thys, const AjPStr maskchar, AjPSeq seq)
     else
     {
 	str = ajStrNew();
+
 	for(jj=0; jj<=ajStrGetLen(str); ++jj)
 	    ajStrInsertS(&str, jj, maskchar);
+
 	ajSeqAssignSeqS(seq, str);
 	ajStrDel(&str);
     }
@@ -1072,6 +1363,7 @@ AjBool ajRangeSeqToLower(const AjPRange thys, AjPSeq seq)
 	substr = ajStrNew();
 	str = ajStrNew();
 	seqstr = ajSeqGetSeqS(seq);
+
 	for(i=0; i<nr; ++i)
 	{
 	    if(!ajRangeValues(thys,i,&st,&en))
@@ -1090,13 +1382,11 @@ AjBool ajRangeSeqToLower(const AjPRange thys, AjPSeq seq)
 	    ajStrInsertS(&str, st, substr);
 	    ajStrSetClear(&substr);        
 	}
+
 	ajStrDel(&substr);
     }
     else
-    {
 	ajSeqFmtLower(seq);
-    }
-
     
     return result;
 }
@@ -1179,7 +1469,6 @@ AjBool ajRangeStrExtract(const AjPRange thys, const AjPStr instr,
     ajDebug("ajRangeStrExtract Number:%d\n", nr);
 
     if (nr)
-    {
 	for(i=0; i<nr; i++)
 	{
 	    result = ajTrue;
@@ -1187,11 +1476,8 @@ AjBool ajRangeStrExtract(const AjPRange thys, const AjPStr instr,
 	    ajStrAppendSubS(outstr, instr, st-1, en-1);
 	    ajDebug("Range [%d] %d..%d '%S'\n", i, st, en, *outstr);
 	}
-    }
     else
-    {
 	ajStrAssignS(outstr, instr);
-    }
 
     return result;
 }
@@ -1380,18 +1666,23 @@ ajuint ajRangeOverlapSingle(ajuint start, ajuint end,
 
     if(end < pos || start > posend)
 	return 0;
+
     /* no overlap 		~~~~ |--------|	*/
     if(start >= pos && end <= posend)
 	return 1;
+
     /* internal overlap	     |-~~~~~--|		*/
     if(start < pos && end > posend)
 	return 2;
+
     /* complete overlap	~~~~~|~~~~~~~~|~~	*/
     if(start < pos && end >= pos )
 	return 3;
+
     /* overlap at left	~~~~~|~~~-----|		*/
     if(start >= pos && end > posend )
 	return 4;
+
     /* overlap at right	     |----~~~~|~~~	*/
 
     ajFatal("ajrangeoverlapsingle error");
@@ -1428,7 +1719,9 @@ ajuint ajRangeOverlaps(const AjPRange thys, ajuint pos, ajuint length)
     for(i=0; i<nr; i++)
     {
 	ajRangeValues(thys,i,&st,&en);
-	if(ajRangeOverlapSingle(st, en, pos, length)) result++;
+
+	if(ajRangeOverlapSingle(st, en, pos, length))
+            result++;
     }
 
     return result;
@@ -1463,8 +1756,10 @@ AjBool ajRangeOrdered(const AjPRange thys)
 	ajRangeValues(thys,i,&st,&en);
 	ajDebug("ajRangeOrdered [%u] st:%u en:%u (last:%u)\n",
 		i, st, en, last);
+
         if(st <= last || en <= st)
 	    return ajFalse;
+
         last = en;
     }
 
@@ -1498,6 +1793,7 @@ AjBool ajRangeDefault(const AjPRange thys, const AjPSeq s)
         ajDebug("ajRangeDefault n:%d begin:%u end:%u\n",
                 thys->n,
                 ajSeqGetBegin(s),ajSeqGetEnd(s));
+
 	return ajTrue;
     }
 
