@@ -49,6 +49,7 @@ static struct binding ** tableFreeSet = NULL;
 
 static void tableStrDel(void** key, void** value, void* cl);
 static void tableStrDelKey(void** key, void** value, void* cl);
+static void tableFreeSetExpand (void);
 
 
 /* @filesection ajtable ********************************************************
@@ -131,6 +132,8 @@ static ajuint tableHashAtom(const void *key, ajuint hashsize)
 }
 
 
+
+
 /* @section Constructors ******************************************************
 **
 ** Constructors for hash tables
@@ -197,7 +200,7 @@ AjPTable ajTableNewFunctionLen(ajuint size,
     for(i = 1; primes[i] < hint; i++); /* else use default i=0 */
 
     iprime = primes[i-1];
-    ajDebug("ajTableNewFunctionLen hint %d size %d\n", hint, iprime);
+    /*ajDebug("ajTableNewFunctionLen hint %d size %d\n", hint, iprime);*/
 
     table = AJALLOC(sizeof(*table) +
 		    iprime*sizeof(table->buckets[0]));
@@ -208,6 +211,7 @@ AjPTable ajTableNewFunctionLen(ajuint size,
 
     for(i = 0; i < table->size; i++)
 	table->buckets[i] = NULL;
+
     table->length = 0;
     table->timestamp = 0;
 
@@ -224,6 +228,9 @@ AjPTable ajTableNewFunctionLen(ajuint size,
     return table;
 }
 
+
+
+
 /* @obsolete ajTableNewL
 ** @rename ajTableNewFunctionLen
 */
@@ -251,6 +258,8 @@ __deprecated AjPTable ajTableNew(ajuint hint,
 }
 
 
+
+
 /* @func ajTableNewLen *********************************************************
 **
 ** creates, initialises, and returns a new, empty table that expects
@@ -272,6 +281,9 @@ AjPTable ajTableNewLen(ajuint size)
     return ajTableNewFunctionLen(size, tableCmpAtom, tableHashAtom);
 }
 
+
+
+
 /* @section Retrieval **********************************************************
 **
 ** @fdata [AjPTable]
@@ -318,10 +330,12 @@ void * ajTableFetch(const AjPTable table, const void *key)
 
     if(!table)
 	return NULL;
+
     if (!key)
 	return NULL;
 
     i = (*table->hash)(key, table->size);
+
     for(p = table->buckets[i]; p; p = p->link)
 	if((*table->cmp)(key, p->key) == 0)
 	    break;
@@ -329,6 +343,9 @@ void * ajTableFetch(const AjPTable table, const void *key)
     return p ? p->value : NULL;
 }
 
+
+
+
 /* @obsolete ajTableGet
 ** @rename ajTableFetch
 */
@@ -339,6 +356,8 @@ __deprecated void * ajTableGet(const AjPTable table, const void *key)
 }
 
 
+
+
 /* @func ajTableFetchKey ******************************************************
 **
 ** returns the key value associated with key in table, or null
@@ -360,10 +379,12 @@ const void * ajTableFetchKey(const AjPTable table, const void *key)
 
     if (!table)
 	return NULL;
+
     if (!key)
 	return NULL;
 
     i = (*table->hash)(key, table->size);
+
     for(p = table->buckets[i]; p; p = p->link)
 	if((*table->cmp)(key, p->key) == 0)
 	    break;
@@ -371,6 +392,9 @@ const void * ajTableFetchKey(const AjPTable table, const void *key)
     return p ? (const void*)p->key : NULL;
 }
 
+
+
+
 /* @obsolete ajTableKey
 ** @rename ajTableGetKey
 */
@@ -380,6 +404,9 @@ __deprecated const void * ajTableKey(const AjPTable table, const void *key)
     return ajTableFetchKey(table, key);
 }
 
+
+
+
 /* @func ajTableGetLength ****************************************************
 **
 ** returns the number of key-value pairs in table.
@@ -399,6 +426,9 @@ ajuint ajTableGetLength(const AjPTable table)
     return table->length;
 }
 
+
+
+
 /* @obsolete ajTableLength
 ** @rename ajTableGetLength
 */
@@ -408,21 +438,21 @@ __deprecated ajint ajTableLength(const AjPTable table)
     return (ajuint) ajTableGetLength(table);
 }
 
+
+
+
 /* @func ajTableToarray *******************************************************
 **
-** creates a 2N+1 element array that holds the N key-value pairs
-** in table in an unspecified order and returns a pointer to the
-** first element. The keys appear in the even-numbered array
-** elements and the corresponding values appear in the following
-** odd-numbered elements; element 2N is end.
+** creates two N+1 element arrays that holds the N key-value pairs
+** in table in an unspecified order and returns the number of elements.
+** The final element of the array is NULL.
 **
 ** @param [r] table [const AjPTable] Table
 ** @param [w] keyarray [void***] NULL terminated array of keys.
-** @param [w] valarray [void***] NULL terminated array of s.
+** @param [w] valarray [void***] NULL terminated array of values.
 ** @return [ajuint] size of arrays returned
-** @category cast [AjPTable] Creates an array to hold each key
-**                value pair in pairs of array elements. The last
-**                element is null.
+** @category cast [AjPTable] Creates two array to hold each key
+**                value pair. The last element of each array is null.
 ** @@
 ******************************************************************************/
 
@@ -504,10 +534,10 @@ void ajTableTrace(const AjPTable table)
 	if(table->buckets[i])
 	{
 	    j = 0;
+
 	    for(p = table->buckets[i]; p; p = p->link)
-	    {
 		j++;
-	    }
+
 	    k += j;
 	}
 
@@ -518,6 +548,7 @@ void ajTableTrace(const AjPTable table)
 
 
 
+
 /* @section Adding values ******************************************************
 **
 ** @fdata [AjPTable]
@@ -561,10 +592,12 @@ void * ajTablePut(AjPTable table, void *key, void *value)
 
     if(!table)
 	return NULL;
+
     if(!key)
 	return NULL;
 
     i = (*table->hash)(key, table->size);
+
     for(p = table->buckets[i]; p; p = p->link)
 	if((*table->cmp)(key, p->key) == 0)
 	    break;
@@ -575,6 +608,7 @@ void * ajTablePut(AjPTable table, void *key, void *value)
             p = tableFreeSet[--tableFreeNext];
         else
             AJNEW0(p);
+
 	p->key = key;
 	p->link = table->buckets[i];
 	table->buckets[i] = p;
@@ -592,6 +626,9 @@ void * ajTablePut(AjPTable table, void *key, void *value)
     return prev;
 }
 
+
+
+
 /* @func ajTableRemove ********************************************************
 **
 ** Removes the key-value pair from table and returns the removed
@@ -614,22 +651,27 @@ void * ajTableRemove(AjPTable table, const void *key)
 
     if(!table)
 	return NULL;
+
     if(!key)
 	return NULL;
 
     table->timestamp++;
     i = (*table->hash)(key, table->size);
+
     for(pp = &table->buckets[i]; *pp; pp = &(*pp)->link)
 	if((*table->cmp)(key, (*pp)->key) == 0)
 	{
 	    struct binding *p = *pp;
 	    void *value = p->value;
 	    *pp = p->link;
+
             if(tableFreeNext >= tableFreeMax)
                 AJFREE(p);
             else
                 tableFreeSet[tableFreeNext++] = p;
+
 	    table->length--;
+
 	    return value;
 	}
 
@@ -662,11 +704,13 @@ void * ajTableRemoveKey(AjPTable table, const void *key, void** truekey)
 
     if(!table)
 	return NULL;
+
     if(!key)
 	return NULL;
 
     table->timestamp++;
     i = (*table->hash)(key, table->size);
+
     for(pp = &table->buckets[i]; *pp; pp = &(*pp)->link)
 	if((*table->cmp)(key, (*pp)->key) == 0)
 	{
@@ -674,11 +718,14 @@ void * ajTableRemoveKey(AjPTable table, const void *key, void** truekey)
 	    void *value = p->value;
 	    *truekey = p->key;
 	    *pp = p->link;
+
             if(tableFreeNext >= tableFreeMax)
                 AJFREE(p);
             else
                 tableFreeSet[tableFreeNext++] = p;
+
 	    table->length--;
+
 	    return value;
 	}
 
@@ -738,6 +785,7 @@ void ajTableMap(AjPTable table,
 	return;
 
     stamp = table->timestamp;
+
     for(i = 0; i < table->size; i++)
 	for(p = table->buckets[i]; p; p = p->link)
 	{
@@ -774,18 +822,31 @@ void ajTableMapDel(AjPTable table,
 {
     ajuint i;
     ajuint stamp;
-    struct binding *p;
+    struct binding *p, *q;
 
     if(!table)
 	return;
 
     stamp = table->timestamp;
+
     for(i = 0; i < table->size; i++)
-	for(p = table->buckets[i]; p; p = p->link)
+    {
+	for(p = table->buckets[i]; p; p = q)
 	{
+            q = p->link;
+
 	    apply(&p->key, &p->value, cl);
 	    assert(table->timestamp == stamp);
+            table->length--;
+            if(tableFreeNext >= tableFreeMax)
+                tableFreeSetExpand();
+            if(tableFreeNext >= tableFreeMax)
+                AJFREE(p);
+            else
+                tableFreeSet[tableFreeNext++] = p;
 	}
+        table->buckets[i] = NULL;
+    }
 
     return;
 }
@@ -820,17 +881,22 @@ void ajTableMapDel(AjPTable table,
 static void tableFreeSetExpand (void)
 {
     ajint newsize;
+
     if(!tableFreeSet)
     {
         tableFreeMax = 1024;
         AJCNEW0(tableFreeSet,tableFreeMax);
+
         return;
     }
+
     if(tableFreeMax >= 65536)
         return;
+
     newsize = tableFreeMax + tableFreeMax;
     AJCRESIZE0(tableFreeSet, tableFreeMax, newsize);
     tableFreeMax = newsize;
+
     return;
 }
 
@@ -859,10 +925,13 @@ void ajTableFree(AjPTable* Ptable)
     if((*Ptable)->length > 0)
     {
 	struct binding *p, *q;
+
 	for(i = 0; i < (*Ptable)->size; i++)
-	    for(p = (*Ptable)->buckets[i]; p; p = q)
+	{
+            for(p = (*Ptable)->buckets[i]; p; p = q)
 	    {
 		q = p->link;
+
                 if(tableFreeNext >= tableFreeMax)
                     tableFreeSetExpand();
                 if(tableFreeNext >= tableFreeMax)
@@ -870,6 +939,8 @@ void ajTableFree(AjPTable* Ptable)
                 else
                     tableFreeSet[tableFreeNext++] = p;
             }
+            (*Ptable)->buckets[i] = NULL;
+        }
     }
 
     AJFREE(*Ptable);
@@ -880,7 +951,6 @@ void ajTableFree(AjPTable* Ptable)
 
 
 
-
 /* @section exit **************************************************************
 **
 ** Functions called on exit from the program by ajExit to do
@@ -931,6 +1001,8 @@ void ajTableExit(void)
 }
 
 
+
+
 /* @datasection [AjPTable] String hash tables *********************************
 **
 ** @nam2rule Tablestr String hash tables
@@ -939,6 +1011,7 @@ void ajTableExit(void)
 
 
 
+
 /* @section Constructors ******************************************************
 **
 ** Constructors for hash tables
@@ -995,7 +1068,6 @@ AjPTable ajTablestrNewCase(void)
 
 
 
-
 /* @func ajTablestrNewCaseLen *************************************************
 **
 ** Creates, initialises, and returns a new, empty table that can hold a
@@ -1016,6 +1088,8 @@ AjPTable ajTablestrNewCaseLen(ajuint size)
 }
 
 
+
+
 /* @func ajTablestrNewLen *****************************************************
 **
 ** Creates, initialises, and returns a new, empty table that can hold a
@@ -1074,10 +1148,12 @@ const AjPStr ajTablestrFetch(const AjPTable table, const AjPStr key)
 
     if(!table)
 	return NULL;
+
     if (!key)
 	return NULL;
 
     i = (*table->hash)(key, table->size);
+
     for(p = table->buckets[i]; p; p = p->link)
 	if((*table->cmp)(key, p->key) == 0)
 	    break;
@@ -1085,6 +1161,9 @@ const AjPStr ajTablestrFetch(const AjPTable table, const AjPStr key)
     return p ? (const AjPStr) p->value : NULL;
 }
 
+
+
+
 /* @section Modify ************************************************************
 **
 ** @fdata [AjPTable]
@@ -1121,10 +1200,12 @@ AjPStr* ajTablestrFetchmod(AjPTable table, const AjPStr key)
 
     if(!table)
 	return NULL;
+
     if (!key)
 	return NULL;
 
     i = (*table->hash)(key, table->size);
+
     for(p = table->buckets[i]; p; p = p->link)
 	if((*table->cmp)(key, p->key) == 0)
 	    break;
@@ -1132,6 +1213,9 @@ AjPStr* ajTablestrFetchmod(AjPTable table, const AjPStr key)
     return p ? (AjPStr*) (&p->value) : NULL;
 }
 
+
+
+
 /* @section Comparison functions **********************************************
 **
 ** @fdata [AjPTable]
@@ -1177,6 +1261,9 @@ ajint ajTablestrCmp(const void* x, const void* y)
     return (ajint)ajStrCmpS(sx, sy);
 }
 
+
+
+
 /* @obsolete ajStrTableCmp
 ** @rename ajTablestrCmp
 */
@@ -1186,6 +1273,9 @@ __deprecated ajint ajStrTableCmp(const void* x, const void* y)
     return ajTablestrCmp(x, y);
 }
 
+
+
+
 /* @func ajTablestrCmpCase ****************************************************
 **
 ** Comparison function for a table with a string key
@@ -1209,6 +1299,9 @@ ajint ajTablestrCmpCase(const void* x, const void* y)
     return (ajint)ajStrCmpCaseS(sx, sy);
 }
 
+
+
+
 /* @obsolete ajStrTableCmpCase
 ** @rename ajTablestrCmpCase
 */
@@ -1219,6 +1312,8 @@ __deprecated ajint ajStrTableCmpCase(const void* x, const void* y)
 }
 
 
+
+
 /* @func ajTablestrHash *******************************************************
 **
 ** Hash function for a table with a string key
@@ -1244,6 +1339,9 @@ ajuint ajTablestrHash(const void* key, ajuint hashsize)
     return hash;
 }
 
+
+
+
 /* @obsolete ajStrTableHash
 ** @rename ajTablestrHash
 */
@@ -1254,6 +1352,8 @@ __deprecated ajuint ajStrTableHash(const void* key, ajuint hashsize)
 }
 
 
+
+
 /* @func ajTablestrHashCase ***************************************************
 **
 ** Hash function for a table with a string key and
@@ -1281,6 +1381,8 @@ ajuint ajTablestrHashCase(const void* key, ajuint hashsize)
 }
 
 
+
+
 /* @obsolete ajStrTableHashCase
 ** @rename ajTablestrHashCase
 */
@@ -1290,6 +1392,9 @@ __deprecated ajuint ajStrTableHashCase(const void* key, ajuint hashsize)
     return ajTablestrHashCase(key, hashsize);
 }
 
+
+
+
 /* @section Trace functions ***************************************************
 **
 ** @fdata [AjPTable]
@@ -1322,17 +1427,18 @@ void ajTablestrPrint(const AjPTable table)
 
     if(!table)
 	return;
+
     for(i = 0; i < table->size; i++)
 	for(p = table->buckets[i]; p; p = p->link)
-	{
 	    ajUser("key '%S' value '%S'",
 		   (const AjPStr) p->key, (AjPStr) p->value);
-	}
 
     return;
 }
 
 
+
+
 /* @obsolete ajStrTablePrint
 ** @rename ajTablestrPrint
 */
@@ -1342,6 +1448,9 @@ __deprecated void ajStrTablePrint(const AjPTable table)
     ajTablestrPrint(table);
 }
 
+
+
+
 /* @func ajTablestrTrace ******************************************************
 **
 ** Writes debug messages to trace the contents of a table,
@@ -1372,12 +1481,14 @@ void ajTablestrTrace(const AjPTable table)
 	{
 	    j = 0;
 	    ajDebug("buckets[%d]\n", i);
+
 	    for(p = table->buckets[i]; p; p = p->link)
 	    {
 		ajDebug("   '%S' => '%S'\n",
 			(const AjPStr) p->key, (AjPStr) p->value);
 		j++;
 	    }
+
 	    k += j;
 	}
 
@@ -1386,6 +1497,9 @@ void ajTablestrTrace(const AjPTable table)
     return;
 }
 
+
+
+
 /* @obsolete ajStrTableTrace
 ** @rename ajTablestrTrace
 */
@@ -1393,9 +1507,13 @@ void ajTablestrTrace(const AjPTable table)
 __deprecated void ajStrTableTrace(const AjPTable table)
 {
     ajTablestrTrace(table);
+
     return;
 }
 
+
+
+
 /* @section Destructors *******************************************************
 **
 ** @fdata [AjPTable]
@@ -1439,6 +1557,8 @@ void ajTablestrFree(AjPTable* Ptable)
 }
 
 
+
+
 /* @obsolete ajStrTableFree
 ** @rename ajTablestrFree
 */
@@ -1446,9 +1566,13 @@ void ajTablestrFree(AjPTable* Ptable)
 __deprecated void ajStrTableFree(AjPTable* ptable)
 {
     ajTablestrFree(ptable);
+
     return;
 }
 
+
+
+
 /* @func ajTablestrFreeKey ****************************************************
 **
 ** Free string keys in a table and free the table. Do not free the values.
@@ -1473,6 +1597,9 @@ void ajTablestrFreeKey(AjPTable* Ptable)
     return;
 }
 
+
+
+
 /* @obsolete ajStrTableFreeKey
 ** @rename ajTablestrFreeKey
 */
@@ -1480,10 +1607,13 @@ void ajTablestrFreeKey(AjPTable* Ptable)
 __deprecated void ajStrTableFreeKey(AjPTable* ptable)
 {
     ajTablestrFreeKey(ptable);
+
     return;
 }
 
 
+
+
 /* @funcstatic tableStrDel ****************************************************
 **
 ** Delete an entry in a string table.
@@ -1546,6 +1676,9 @@ static void tableStrDelKey(void** key, void** value, void* cl)
     return;
 }
 
+
+
+
 /* @datasection [AjPTable] Character hash tables *******************************
 **
 ** @nam2rule Tablechar
@@ -1583,6 +1716,9 @@ AjPTable ajTablecharNew(void)
     return ajTableNewFunctionLen(100, ajTablecharCmp, ajTablecharHash);
 }
 
+
+
+
 /* @func ajTablecharNewCase ***************************************************
 **
 ** Creates a table with a character string key and case insensitive searching.
@@ -1596,6 +1732,9 @@ AjPTable ajTablecharNewCase(void)
     return ajTableNewFunctionLen(100, ajTablecharCmpCase, ajTablecharHashCase);
 }
 
+
+
+
 /* @func ajTablecharNewCaseLen ************************************************
 **
 ** Creates a table with a character string key and case insensitive searching.
@@ -1610,6 +1749,9 @@ AjPTable ajTablecharNewCaseLen(ajuint size)
     return ajTableNewFunctionLen(size, ajTablecharCmpCase, ajTablecharHashCase);
 }
 
+
+
+
 /* @obsolete ajStrTableNewCaseC
 ** @rename ajTablecharNewCaseLen
 */
@@ -1619,6 +1761,9 @@ __deprecated AjPTable ajStrTableNewCaseC(ajuint hint)
     return ajTablecharNewCaseLen(hint);
 }
 
+
+
+
 /* @obsolete ajStrTableNewCase
 ** @rename ajTablestrNewCaseLen
 */
@@ -1629,6 +1774,8 @@ __deprecated AjPTable ajStrTableNewCase(ajuint hint)
 }
 
 
+
+
 /* @func ajTablecharNewLen ****************************************************
 **
 ** Creates a table with a character string key.
@@ -1645,6 +1792,7 @@ AjPTable ajTablecharNewLen(ajuint size)
 
 
 
+
 /* @obsolete ajStrTableNewC
 ** @rename ajTablecharNewLen
 */
@@ -1655,6 +1803,8 @@ __deprecated AjPTable ajStrTableNewC(ajuint hint)
 }
 
 
+
+
 /* @obsolete ajStrTableNew
 ** @rename ajTablestrNewLen
 */
@@ -1713,6 +1863,8 @@ ajint ajTablecharCmp(const void* x, const void* y)
 }
 
 
+
+
 /* @obsolete ajStrTableCmpC
 ** @rename ajTablecharCmp
 */
@@ -1722,6 +1874,9 @@ __deprecated ajint ajStrTableCmpC(const void* x, const void* y)
     return ajTablecharCmp(x, y);
 }
 
+
+
+
 /* @func ajTablecharCmpCase ***************************************************
 **
 ** Comparison function for a table with a character string key
@@ -1745,6 +1900,9 @@ ajint ajTablecharCmpCase(const void* x, const void* y)
     return (ajint)ajCharCmpCase(sx, sy);
 }
 
+
+
+
 /* @obsolete ajStrTableCmpCaseC
 ** @rename ajTablecharCmpCase
 */
@@ -1754,6 +1912,9 @@ __deprecated ajint ajStrTableCmpCaseC(const void* x, const void* y)
     return ajTablecharCmpCase(x, y);
 }
 
+
+
+
 /* @func ajTablecharHash ******************************************************
 **
 ** Hash function for a table with a character string key
@@ -1778,6 +1939,8 @@ ajuint ajTablecharHash(const void* key, ajuint hashsize)
 }
 
 
+
+
 /* @obsolete ajStrTableHashC
 ** @rename ajTablecharHash
 */
@@ -1787,6 +1950,9 @@ __deprecated ajuint ajStrTableHashC(const void* key, ajuint hashsize)
     return ajTablecharHash(key, hashsize);
 }
 
+
+
+
 /* @func ajTablecharHashCase **************************************************
 **
 ** Hash function for a table with a character string key and
@@ -1811,6 +1977,9 @@ ajuint ajTablecharHashCase(const void* key, ajuint hashsize)
     return hash;
 }
 
+
+
+
 /* @obsolete ajStrTableHashCaseC
 ** @rename ajTablecharHashCase
 */
@@ -1821,6 +1990,8 @@ __deprecated ajuint ajStrTableHashCaseC(const void* key, ajuint hashsize)
 }
 
 
+
+
 /* @section Trace functions ***************************************************
 **
 ** @fdata [AjPTable]
@@ -1853,6 +2024,7 @@ void ajTablecharPrint(const AjPTable table)
 
     if(!table)
 	return;
+
     for(i = 0; i < table->size; i++)
 	for(p = table->buckets[i]; p; p = p->link)
 	{
@@ -1863,6 +2035,9 @@ void ajTablecharPrint(const AjPTable table)
     return;
 }
 
+
+
+
 /* @obsolete ajStrTablePrintC
 ** @rename ajTablecharPrint
 */
@@ -1870,6 +2045,6 @@ void ajTablecharPrint(const AjPTable table)
 __deprecated void ajStrTablePrintC(const AjPTable table)
 {
     ajTablecharPrint(table);
+
     return;
 }
-
