@@ -198,8 +198,8 @@ int main(int argc, char **argv)
     embInit("eprimer3", argc, argv);
 
     /* Global details */
-    explain_flag     = ajAcdGetBool("explainflag");
-    file_flag        = ajAcdGetBool("fileflag");
+    explain_flag     = ajAcdGetBoolean("explainflag");
+    file_flag        = ajAcdGetBoolean("fileflag");
     task             = ajAcdGetList("task");
     do_primer        = ajAcdGetToggle("primer");
     do_hybrid        = ajAcdGetToggle("hybridprobe");
@@ -215,7 +215,7 @@ int main(int argc, char **argv)
     right_input     = ajAcdGetString("reverseinput");
 
     /* Primer details */
-    pick_anyway         = ajAcdGetBool("pickanyway");
+    pick_anyway         = ajAcdGetBoolean("pickanyway");
     mispriming_library  = ajAcdGetInfile("mispriminglibraryfile");
     max_mispriming      = ajAcdGetFloat("maxmispriming");
     pair_max_mispriming = ajAcdGetFloat("pairmaxmispriming");
@@ -248,11 +248,11 @@ int main(int argc, char **argv)
        */
 
     /* Product details */
-    product_opt_size    = ajAcdGetInt("productosize");
-    product_size_range  = ajAcdGetRange("productsizerange");
-    product_opt_tm      = ajAcdGetFloat("productotm");
-    product_min_tm      = ajAcdGetFloat("productmintm");
-    product_max_tm      = ajAcdGetFloat("productmaxtm");
+    product_opt_size    = ajAcdGetInt("psizeopt");
+    product_size_range  = ajAcdGetRange("prange");
+    product_opt_tm      = ajAcdGetFloat("ptmopt");
+    product_min_tm      = ajAcdGetFloat("ptmmin");
+    product_max_tm      = ajAcdGetFloat("ptmmax");
 
     /* Objective Function Penalty Weights for Primers */
     max_end_stability   = ajAcdGetFloat("maxendstability");
@@ -266,26 +266,26 @@ int main(int argc, char **argv)
     /* these are not (yet) implemented */
 
     /* Internal Oligo "Sequence" Input Tags */
-    internal_oligo_excluded_region = ajAcdGetRange("oligoexcludedregion");
+    internal_oligo_excluded_region = ajAcdGetRange("oexcludedregion");
     internal_oligo_input           = ajAcdGetString("oligoinput");
 
     /* Internal Oligo "Global" Input Tags */
-    internal_oligo_opt_size       = ajAcdGetInt("oligoosize");
-    internal_oligo_min_size       = ajAcdGetInt("oligominsize");
-    internal_oligo_max_size       = ajAcdGetInt("oligomaxsize");
-    internal_oligo_opt_tm         = ajAcdGetFloat("oligootm");
-    internal_oligo_min_tm         = ajAcdGetFloat("oligomintm");
-    internal_oligo_max_tm         = ajAcdGetFloat("oligomaxtm");
-    internal_oligo_opt_gc_percent = ajAcdGetFloat("oligoogcpercent");
-    internal_oligo_min_gc         = ajAcdGetFloat("oligomingc");
-    internal_oligo_max_gc         = ajAcdGetFloat("oligomaxgc");
-    internal_oligo_salt_conc      = ajAcdGetFloat("oligosaltconc");
-    internal_oligo_dna_conc       = ajAcdGetFloat("oligodnaconc");
-    internal_oligo_self_any       = ajAcdGetFloat("oligoselfany");
-    internal_oligo_self_end       = ajAcdGetFloat("oligoselfend");
-    internal_oligo_max_poly_x     = ajAcdGetInt("oligomaxpolyx");
-    internal_oligo_mishyb_library = ajAcdGetInfile("oligomishyblibraryfile");
-    internal_oligo_max_mishyb     = ajAcdGetFloat("oligomaxmishyb");
+    internal_oligo_opt_size       = ajAcdGetInt("osizeopt");
+    internal_oligo_min_size       = ajAcdGetInt("ominsize");
+    internal_oligo_max_size       = ajAcdGetInt("omaxsize");
+    internal_oligo_opt_tm         = ajAcdGetFloat("otmopt");
+    internal_oligo_min_tm         = ajAcdGetFloat("otmmin");
+    internal_oligo_max_tm         = ajAcdGetFloat("otmmax");
+    internal_oligo_opt_gc_percent = ajAcdGetFloat("ogcopt");
+    internal_oligo_min_gc         = ajAcdGetFloat("ogcmin");
+    internal_oligo_max_gc         = ajAcdGetFloat("ogcmax");
+    internal_oligo_salt_conc      = ajAcdGetFloat("osaltconc");
+    internal_oligo_dna_conc       = ajAcdGetFloat("odnaconc");
+    internal_oligo_self_any       = ajAcdGetFloat("oanyself");
+    internal_oligo_self_end       = ajAcdGetFloat("oendself");
+    internal_oligo_max_poly_x     = ajAcdGetInt("opolyxmax");
+    internal_oligo_mishyb_library = ajAcdGetInfile("mishyblibraryfile");
+    internal_oligo_max_mishyb     = ajAcdGetFloat("omishybmax");
     /*
        internal_oligo_min_quality    = ajAcdGetInt("oligominquality");
     */
@@ -298,6 +298,9 @@ int main(int argc, char **argv)
     outfile = ajAcdGetOutfile("outfile");
     
     
+    ajStrRemoveWhite(&left_input);
+    ajStrRemoveWhite(&right_input);
+
     /*
     ** OK - we will now try to do a separate fork-exec for each sequence.
     */
@@ -386,6 +389,9 @@ int main(int argc, char **argv)
 		 hSaveStdout = GetStdHandle(STD_OUTPUT_HANDLE);
 		 if (!CreatePipe(&hChildStdoutRd, &hChildStdoutWr, &saAttr, 0))
 		     ajFatal ( "Couldn't open pipe() from" );
+
+		 SetHandleInformation(hChildStdoutRd,HANDLE_FLAG_INHERIT,0);
+
 		 if (!SetStdHandle(STD_OUTPUT_HANDLE, hChildStdoutWr)) 
 		     ajFatal("Redirecting STDOUT failed");
 		 fSuccess = DuplicateHandle(GetCurrentProcess(),
@@ -504,7 +510,7 @@ int main(int argc, char **argv)
             /* mispriming library may not have been specified */
             if(mispriming_library)
             eprimer3_send_stringC(stream, "PRIMER_MISPRIMING_LIBRARY",
-                                  ajFileName(mispriming_library));
+                                  ajFileGetNameC(mispriming_library));
     
             eprimer3_send_float(stream, "PRIMER_MAX_MISPRIMING", 
                                 max_mispriming);
@@ -579,7 +585,7 @@ int main(int argc, char **argv)
             if(internal_oligo_mishyb_library)
                 eprimer3_send_stringC(stream,
                     "PRIMER_INTERNAL_OLIGO_MISHYB_LIBRARY",
-                    ajFileName(internal_oligo_mishyb_library));
+                    ajFileGetNameC(internal_oligo_mishyb_library));
 
             eprimer3_send_float(stream, "PRIMER_INTERNAL_OLIGO_MAX_MISHYB",
                     internal_oligo_max_mishyb);
@@ -642,9 +648,10 @@ int main(int argc, char **argv)
     
             ajStrSetClear(&result);
 
-            close( pipeto[1] );
+#ifndef WIN32
+            close(pipeto[1]);
             close(pipefrom[0]);
-            
+#endif            
         }	/* end of parent/child fork */
 
     }	/* end of sequence loop */
