@@ -365,7 +365,7 @@ int main(int argc, char **argv)
 {
     AjPSeqall seqall;
     AjPSeq    seq  = NULL;
-    AjPFile   outf = NULL;
+    AjPFile   outf = NULL;      /* no longer used */
     AjPReport report = NULL;
     AjPFeattable TabRpt = NULL;
     AjPStr    strand = NULL;
@@ -412,7 +412,7 @@ int main(int argc, char **argv)
 	ajReportWrite(report, TabRpt, seq);
 	ajFeattableDel(&TabRpt);
     }
-
+    ajReportSetSeqstats(report, seqall);
 
     ajSeqDel(&seq);
     ajStrDel(&substr);
@@ -668,10 +668,10 @@ static void garnier_report(AjPReport report, AjPFeattable TabRpt,
 
     if(!strHelix)
     {
-	ajStrAssignC(&strHelix, "helix");
-	ajStrAssignC(&strExtend, "strand");
-	ajStrAssignC(&strTurns, "turn");
-	ajStrAssignC(&strCoil, "coil");
+	ajStrAssignC(&strHelix, "SO:0001117");  /* alpha_helix */
+	ajStrAssignC(&strExtend, "SO:0001111"); /* beta_strand */
+	ajStrAssignC(&strTurns, "SO:0001128");  /* turn */
+	ajStrAssignC(&strCoil, "SO:0100012");   /* coil (unstructured) */
     }
     
     idc = Idc;
@@ -774,22 +774,22 @@ static void garnier_report(AjPReport report, AjPFeattable TabRpt,
 		{
 		case 'H':
 		    gf = ajFeatNewProt(TabRpt, NULL, strHelix, l0, ito, 0.0);
-		    ajFmtPrintS(&tmpStr, "*helix H");
+		    ajFmtPrintS(&tmpStr, "*garnier H");
 		    ajFeatTagAdd(gf,  NULL, tmpStr);
 		    break;
 		case 'E':
 		    gf = ajFeatNewProt(TabRpt, NULL, strExtend, l0, ito, 0.0);
-		    ajFmtPrintS(&tmpStr, "*sheet E");
+		    ajFmtPrintS(&tmpStr, "*garnier E");
 		    ajFeatTagAdd(gf,  NULL, tmpStr);
 		    break;
 		case 'T':
 		    gf = ajFeatNewProt(TabRpt, NULL, strTurns, l0, ito, 0.0);
-		    ajFmtPrintS(&tmpStr, "*turns T");
+		    ajFmtPrintS(&tmpStr, "*garnier T");
 		    ajFeatTagAdd(gf,  NULL, tmpStr);
 		    break;
 		case 'C':
 		    gf = ajFeatNewProt(TabRpt, NULL, strCoil, l0, ito, 0.0);
-		    ajFmtPrintS(&tmpStr, "*coil C");
+		    ajFmtPrintS(&tmpStr, "*garnier C");
 		    ajFeatTagAdd(gf,  NULL, tmpStr);
 		    break;
 		default:
