@@ -135,8 +135,10 @@ int main(int argc, char **argv)
     AjBool plasmid;
     AjBool commercial;
     AjBool limit;
+    AjBool methyl;
     AjPFile enzfile  = NULL;
     AjPFile equfile  = NULL;
+    AjPFile methfile = NULL;
     AjPTable retable = NULL;
     ajint hits;
     AjPList restrictlist = NULL;
@@ -148,35 +150,37 @@ int main(int argc, char **argv)
     tablename   = ajAcdGetListSingle("table");
     uppercase   = ajAcdGetRange("uppercase");
     highlight   = ajAcdGetRange("highlight");
-    threeletter = ajAcdGetBool("threeletter");
-    numberseq   = ajAcdGetBool("number");
+    threeletter = ajAcdGetBoolean("threeletter");
+    numberseq   = ajAcdGetBoolean("number");
     width       = ajAcdGetInt("width");
     length      = ajAcdGetInt("length");
     margin      = ajAcdGetInt("margin");
-    nameseq     = ajAcdGetBool("name");
-    description = ajAcdGetBool("description");
+    nameseq     = ajAcdGetBoolean("name");
+    description = ajAcdGetBoolean("description");
     offset      = ajAcdGetInt("offset");
-    html        = ajAcdGetBool("html");
+    html        = ajAcdGetBoolean("html");
     orfminsize  = ajAcdGetInt("orfminsize");
-    translation = ajAcdGetBool("translation");
-    reverse     = ajAcdGetBool("reverse");
-    cutlist     = ajAcdGetBool("cutlist");
-    flat        = ajAcdGetBool("flatreformat");
+    translation = ajAcdGetBoolean("translation");
+    reverse     = ajAcdGetBoolean("reverse");
+    cutlist     = ajAcdGetBoolean("cutlist");
+    flat        = ajAcdGetBoolean("flatreformat");
     framelist   = ajAcdGetList("frame");
     
     /*  restriction enzyme stuff */
     mincuts    = ajAcdGetInt("mincuts");
     maxcuts    = ajAcdGetInt("maxcuts");
     sitelen    = ajAcdGetInt("sitelen");
-    single     = ajAcdGetBool("single");
-    blunt      = ajAcdGetBool("blunt");
-    sticky     = ajAcdGetBool("sticky");
-    ambiguity  = ajAcdGetBool("ambiguity");
-    plasmid    = ajAcdGetBool("plasmid");
-    commercial = ajAcdGetBool("commercial");
-    limit      = ajAcdGetBool("limit");
+    single     = ajAcdGetBoolean("single");
+    blunt      = ajAcdGetBoolean("blunt");
+    sticky     = ajAcdGetBoolean("sticky");
+    ambiguity  = ajAcdGetBoolean("ambiguity");
+    plasmid    = ajAcdGetBoolean("plasmid");
+    commercial = ajAcdGetBoolean("commercial");
+    limit      = ajAcdGetBoolean("limit");
     enzymes    = ajAcdGetString("enzymes");
-
+    methfile   = ajAcdGetDatafile("mfile");
+    methyl     = ajAcdGetBoolean("methylation");
+    
     if(!blunt  && !sticky)
 	ajFatal("Blunt/Sticky end cutters shouldn't both be disabled.");
 
@@ -233,13 +237,13 @@ int main(int argc, char **argv)
 	if(single)
 	    maxcuts=mincuts=1;
 	retable = ajTablestrNewLen(EQUGUESS);
-	ajFileDataNewC(ENZDATA, &enzfile);
+	enzfile = ajDatafileNewInNameC(ENZDATA);
 	if(!enzfile)
 	    ajFatal("Cannot locate enzyme file. Run REBASEEXTRACT");
 
 	if(limit)
 	{
-	    ajFileDataNewC(EQUDATA,&equfile);
+	    equfile = ajDatafileNewInNameC(EQUDATA);
 	    if(!equfile)
 		limit = ajFalse;
 	    else
@@ -249,9 +253,10 @@ int main(int argc, char **argv)
 	ajFileSeek(enzfile, 0L, 0);
 	restrictlist = ajListNew();
 	/* search for hits, but don't use mincuts and maxcuts criteria yet */
-	hits = embPatRestrictMatch(seq, begin+1, end+1, enzfile, enzymes,
-				   sitelen,plasmid, ambiguity, default_mincuts,
-				   default_maxcuts, blunt, sticky, commercial,
+	hits = embPatRestrictMatch(seq, begin+1, end+1, enzfile, methfile,
+                                   enzymes, sitelen,plasmid, ambiguity,
+                                   default_mincuts, default_maxcuts, blunt,
+                                   sticky, commercial, methyl,
 				   restrictlist);
 
 	ajDebug("Remap found %d hits\n", hits);
@@ -267,6 +272,7 @@ int main(int argc, char **argv)
 
 
 	ajFileClose(&enzfile);
+	ajFileClose(&methfile);
 
 
 	/*
@@ -618,7 +624,7 @@ static void remap_CutList(AjPFile outfile, const AjPTable hittable,
 
 	for(i = 0; keyarray[i]; i++)
 	{
-	    value = (PValue) valarray[i];
+	    value = ajTableFetch(hittable,keyarray[i]);
 	    if(value->count > maxcuts)
 	    ajFmtPrintF(outfile, "%10S\t    %d\t%S\n",
 			    (AjPStr) keyarray[i], value->count,
@@ -768,7 +774,7 @@ static void remap_NoCutList(AjPFile outfile, const AjPTable hittable,
 	}
     }
 
-    ajFileDataNewC(ENZDATA, &enzfile);
+    enzfile = ajDatafileNewInNameC(ENZDATA);
 
     /* push all enzyme names without the required criteria onto nocutlist */
 
@@ -1034,7 +1040,7 @@ static void remap_read_equiv(AjPFile *equfile, AjPTable *table,
 
     line = ajStrNew();
 
-    while(ajFileReadLine(*equfile,&line))
+    while(ajReadlineTrim(*equfile,&line))
     {
         p = ajStrGetPtr(line);
 
@@ -1078,14 +1084,14 @@ static void remap_read_file_of_enzyme_names(AjPStr *enzymes)
     if(ajStrFindC(*enzymes, "@") == 0)
     {
 	ajStrTrimC(enzymes, "@");	/* remove the @ */
-	file = ajFileNewIn(*enzymes);
+	file = ajFileNewInNameS(*enzymes);
 	if(file == NULL)
 	    ajFatal("Cannot open the file of enzyme names: '%S'", enzymes);
 
 	/* blank off the enzyme file name and replace with the enzyme names */
 	ajStrSetClear(enzymes);
 	line = ajStrNew();
-	while(ajFileReadLine(file, &line))
+	while(ajReadlineTrim(file, &line))
 	{
 	    p = ajStrGetPtr(line);
 	    if(!*p || *p == '#' || *p == '!')
