@@ -91,17 +91,19 @@ int main(int argc, char **argv)
     embInit("sirna",argc,argv);
 
     seqall    = ajAcdGetSeqall("sequence");
-    poliii    = ajAcdGetBool("poliii");
-    aa        = ajAcdGetBool("aa");
-    tt        = ajAcdGetBool("tt");
-    polybase  = ajAcdGetBool("polybase");
-    context   = ajAcdGetBool("context");
+    poliii    = ajAcdGetBoolean("poliii");
+    aa        = ajAcdGetBoolean("aa");
+    tt        = ajAcdGetBoolean("tt");
+    polybase  = ajAcdGetBoolean("polybase");
+    context   = ajAcdGetBoolean("context");
     report    = ajAcdGetReport("outfile");
     seqout    = ajAcdGetSeqoutall("outseq");
 
     while(ajSeqallNext(seqall, &seq))
 	sirna_report(report, seq, poliii, aa, tt, polybase, context, seqout);
 
+    ajReportSetSeqstats(report, seqall);
+
     ajSeqallDel(&seqall);
     ajSeqDel(&seq);
     ajReportClose(report);
