@@ -33,14 +33,19 @@
 
 __noreturn void embExit (void)
 {
+    embSigExit();
     embDbiExit();
     embGrpExit();
     embIndexExit();
     embWordExit();
+    embPatlistExit();
 
     ajExit();
 }
 
+
+
+
 /* @func embExitBad ***********************************************************
 **
 ** Cleans up as necessary, and calls ajExitBad
