@@ -7,6 +7,7 @@
 ** @modified 1 Sept 2000 - GWW - Added embPropTransition embPropTranversion
 ** @modified 4 July 2001 - DMAM - Modified embPropAminoRead embPropCalcMolwt
 ** @modified 4 July 2001 - DMAM - Added embPropCalcMolwtMod
+** @modified 1 July 2008 - JISON - Added embPropGet* functions
 ** @@
 **
 ** This program is free software; you can redistribute it and/or
@@ -31,7 +32,9 @@
 #include <ctype.h>
 
 char dayhoffstr[] = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
-float dayhoff[] = {
+
+float dayhoff[] =
+{
     (float) 8.6, (float) 0.0, (float) 2.9, (float) 5.5, (float) 6.0,
     (float) 3.6, (float) 8.4, (float) 2.0, (float) 4.5, (float) 0.0,
     (float) 6.6, (float) 7.4, (float) 1.7, (float) 4.3, (float) 0.0,
@@ -55,9 +58,8 @@ float dayhoff[] = {
 
 #define AMINODATFILE "Eamino.dat"
 
-static AjBool propInit = 0;
 
-double *EmbPropTable[EMBPROPSIZE];
+/* static AjBool propInit = 0;*/
 
 static char propPurines[]     = "agrAGR";
 static char propPyrimidines[] = "ctuyCTUY";
@@ -70,66 +72,424 @@ static ajint propFragCompare(const void *a, const void *b);
 
 
 
-/* @func embPropAminoRead *****************************************************
+/* @func embPropEaminoRead ****************************************************
 **
 ** Read amino acid properties from Eamino.dat
 **
 ** @param [u] mfptr [AjPFile] Input file object
-** @return [void]
+** @return [EmbPPropAmino*] array of amino acid properties
 ** @@
 ******************************************************************************/
 
-void embPropAminoRead(AjPFile mfptr)
+EmbPPropAmino* embPropEaminoRead(AjPFile mfptr)
 {
     AjPStr  line  = NULL;
-    AjPStr  delim = NULL;
-#ifndef WIN32
-    static const char *delimstr=" :\t\n";
-#else
-    static const char *delimstr=" :\t\n\r";
-#endif
-
+    AjPStr  token = NULL;
+    
+    AjBool firstline;
+    
     const char *p;
     ajuint i;
-    ajint cols = 0;
-
-    if(propInit)
-	return;
-
-    for(i=0;i<EMBPROPSIZE;i++)
-	EmbPropTable[i] = 0;
+    ajint  n;
+    
+    EmbPPropAmino *ret;
 
     line  = ajStrNew();
-    delim = ajStrNewC(delimstr);
+    token = ajStrNew();
+    
+    firstline = ajTrue;
 
-    while(ajFileGets(mfptr, &line))
+    AJCNEW0(ret,EMBPROPSIZE);
+
+    for(i=0; i < EMBPROPSIZE; ++i)
+	AJNEW0(ret[i]);
+    
+    while(ajReadline(mfptr, &line))
     {
+	ajStrRemoveWhiteExcess(&line);
 	p = ajStrGetPtr(line);
+
 	if(*p=='#' || *p=='!' || !*p)
 	    continue;
 
-	while(*p && (*p<'A' || *p>'Z'))
-	    ++p;
+	if(firstline)
+	{
+	    if(!ajStrPrefixC(line,"aa"))
+		ajFatal("Incorrect (old?) format amino data file");
 
-	cols = ajStrParseCountC(line,ajStrGetPtr(delim));
-	if(EmbPropTable[ajAZToInt(toupper((ajint)*p))])
-	    ajWarn("Amino acid property table duplicate record for '%c'",
-		   *p);
-	i = ajAZToInt(toupper((ajint)*p));
-	if(i >= EMBPROPSIZE)
-	    ajWarn("Amino acid property table bad code '%c', index %u",
-		   *p, i);
-	EmbPropTable[i] =
-	    ajArrDoubleLine(line,ajStrGetPtr(delim),2,cols);
+	    firstline = ajFalse;
+	    continue;
+	}
+
+	ajFmtScanS(line,"%S",&token);
+	ajStrFmtUpper(&token);
+
+	if(ajStrGetLen(token) != 1)
+	    ajFatal("Amino file line doesn't begin with a single character");
+
+	i = ajBasecodeToInt((ajint) *ajStrGetPtr(token));
+
+	if(i == 27)
+	    ajFatal("Amino file line doesn't begin with a single A->Z (%S)",
+		    line);
+
+	n = ajFmtScanS(line,"%*s%d%d%d%d%d%d%f%d%d%d",
+		       &ret[i]->tiny,
+		       &ret[i]->sm_all,
+		       &ret[i]->aliphatic,
+		       &ret[i]->aromatic,
+		       &ret[i]->nonpolar,
+		       &ret[i]->polar,
+		       &ret[i]->charge,
+		       &ret[i]->pve,
+		       &ret[i]->nve,
+		       &ret[i]->extcoeff);
+	if(n!= 10)
+	    ajFatal("Only %d columns in amino file - expected %d",n+1,11);
     }
 
+    ajStrDel(&line);
+    ajStrDel(&token);
+
+    return ret;
+}
+
+
+
+
+/* @func embPropGetProperties **************************************************
+**
+** Returns a string containing a list of defined properties
+**
+** @param [r] prop [const EmbPPropAmino] Input properties object
+** @param [w] Pstr [AjPStr*] String of properties separated by commas
+** @return [AjBool] True if properties are defined
+** @@
+******************************************************************************/
+
+AjBool embPropGetProperties(const EmbPPropAmino prop, AjPStr* Pstr)
+{
+    ajStrAssignC(Pstr, "");
+
+    if(prop->tiny)
+        ajStrAppendC(Pstr, "tiny,");
+
+    if(prop->sm_all)
+        ajStrAppendC(Pstr, "small,");
+
+    if(prop->aliphatic)
+        ajStrAppendC(Pstr, "aliphatic,");
+
+    if(prop->aromatic)
+        ajStrAppendC(Pstr, "aromatic,");
+
+    if(prop->polar)
+        ajStrAppendC(Pstr, "polar,");
+
+    if(prop->nonpolar)
+        ajStrAppendC(Pstr, "nonpolar,");
+
+    ajStrTrimEndC(Pstr, ",");
+
+    if(!ajStrGetLen(*Pstr))
+        return ajFalse;
+
+    return ajTrue;
+}
+
+
+
+
+/* @func embPropEmolwtRead ****************************************************
+**
+** Read molecular weights from Emolwt.dat
+**
+** @param [u] mfptr [AjPFile] Input file object
+** @return [EmbPPropMolwt*] array of amino acid molecular weights
+** @@
+******************************************************************************/
+
+EmbPPropMolwt* embPropEmolwtRead(AjPFile mfptr)
+{
+    AjPStr  line  = NULL;
+    AjPStr  token = NULL;
+    
+    AjBool firstline;
+    
+    const char *p;
+    ajuint i;
+    ajint  n;
+    
+    EmbPPropMolwt *ret;
+
+    line  = ajStrNew();
+    token = ajStrNew();
+    
+    firstline = ajTrue;
+
+    AJCNEW0(ret,EMBPROPSIZE+2);
+
+    for(i=0; i < EMBPROPSIZE+2; ++i)
+	AJNEW0(ret[i]);
+    
+    while(ajReadline(mfptr, &line))
+    {
+	ajStrRemoveWhiteExcess(&line);
+	p = ajStrGetPtr(line);
+
+	if(*p=='#' || *p=='!' || !*p)
+	    continue;
+
+	if(firstline)
+	{
+	    if(!ajStrPrefixC(line,"Mol"))
+		ajFatal("Incorrect format molwt file: '%S'", line);
+
+	    firstline = ajFalse;
+	    continue;
+	}
+
+	ajFmtScanS(line,"%S",&token);
+	ajStrFmtUpper(&token);
+
+	if(ajStrGetLen(token) != 1)
+	{
+	    if(ajStrPrefixC(token,"HYDROGEN"))
+	    {
+		if(ajFmtScanS(line,"%*s%lf%lf",
+			      &ret[EMBPROPHINDEX]->average,
+			      &ret[EMBPROPHINDEX]->mono) != 2)
+		    ajFatal("Bad format hydrogen data line");
+	    }
+	    else if(ajStrPrefixC(token,"OXYGEN"))
+	    {
+		if(ajFmtScanS(line,"%*s%lf%lf",
+			      &ret[EMBPROPOINDEX]->average,
+			      &ret[EMBPROPOINDEX]->mono) != 2)
+		    ajFatal("Bad format oxygen data line");
+	    }
+	    else if(ajStrPrefixC(token,"WATER"))
+	    {
+		if(ajFmtScanS(line,"%*s%lf%lf",
+			      &ret[EMBPROPWINDEX]->average,
+			      &ret[EMBPROPWINDEX]->mono) != 2)
+		    ajFatal("Bad format water data line");
+	    }
+	    else
+		ajFatal("Unknown molwt token %S",token);
+
+	    continue;
+	}
+
+
+	i = ajBasecodeToInt((ajint) *ajStrGetPtr(token));
+
+	if(i == 27)
+	    ajFatal("Molwt file line doesn't begin with a single A->Z (%S)",
+		    line);
+
+	n = ajFmtScanS(line,"%*s%lf%lf",
+		       &ret[i]->average,
+		       &ret[i]->mono);
+	if(n != 2)
+	    ajFatal("Only %d columns in amino file - expected %d",n,3);
+    }
 
     ajStrDel(&line);
-    ajStrDel(&delim);
+    ajStrDel(&token);
 
-    propInit = ajTrue;
+    return ret;
+}
 
-    return;
+
+
+
+/* @func embPropMolwtGetMolwt *************************************************
+**
+** Return charge value
+**
+** @param [r] prop [const EmbPPropMolwt] Input mOlecular weights object
+** @return [float] charge
+** @@
+******************************************************************************/
+
+float embPropMolwtGetMolwt(const EmbPPropMolwt prop)
+{
+    float ret;
+
+    ret = (float) prop->average; /* satisfy VC++ */
+    
+    return ret;
+}
+
+
+
+
+/* @func embPropGetCharge *****************************************************
+**
+** Return charge value
+**
+** @param [r] prop [const EmbPPropAmino] Input properties object
+** @return [float] charge
+** @@
+******************************************************************************/
+
+float embPropGetCharge(const EmbPPropAmino prop)
+{
+    return prop->charge;
+}
+
+
+
+
+/* @func embPropGetTiny *****************************************************
+**
+** Return tiny value
+**
+** @param [r] prop [const EmbPPropAmino] Input properties object
+** @return [ajint] tiny
+** @@
+******************************************************************************/
+
+ajint embPropGetTiny(const EmbPPropAmino prop)
+{
+    return prop->tiny;
+}
+
+
+
+
+/* @func embPropGetSmall *****************************************************
+**
+** Return small value
+**
+** @param [r] prop [const EmbPPropAmino] Input properties object
+** @return [ajint] small
+** @@
+******************************************************************************/
+
+ajint embPropGetSmall(const EmbPPropAmino prop)
+{
+    return prop->sm_all;
+}
+
+
+
+
+/* @func embPropGetAliphatic **************************************************
+**
+** Return aliphatic value
+**
+** @param [r] prop [const EmbPPropAmino] Input properties object
+** @return [ajint] aliphatic
+** @@
+******************************************************************************/
+
+ajint embPropGetAliphatic(const EmbPPropAmino prop)
+{
+    return prop->aliphatic;
+}
+
+
+
+
+/* @func embPropGetAromatic ***************************************************
+**
+** Return aromatic value
+**
+** @param [r] prop [const EmbPPropAmino] Input properties object
+** @return [ajint] aromatic
+** @@
+******************************************************************************/
+
+ajint embPropGetAromatic(const EmbPPropAmino prop)
+{
+    return prop->aromatic;
+}
+
+
+
+
+/* @func embPropGetNonpolar ***************************************************
+**
+** Return nonpolar value
+**
+** @param [r] prop [const EmbPPropAmino] Input properties object
+** @return [ajint] nonpolar
+** @@
+******************************************************************************/
+
+ajint embPropGetNonpolar(const EmbPPropAmino prop)
+{
+    return prop->nonpolar;
+}
+
+
+
+
+/* @func embPropGetPolar *****************************************************
+**
+** Return polar value
+**
+** @param [r] prop [const EmbPPropAmino] Input properties object
+** @return [ajint] polar
+** @@
+******************************************************************************/
+
+ajint embPropGetPolar(const EmbPPropAmino prop)
+{
+    return prop->polar;
+}
+
+
+
+
+/* @func embPropGetPve *****************************************************
+**
+** Return pve value
+**
+** @param [r] prop [const EmbPPropAmino] Input properties object
+** @return [ajint] pve
+** @@
+******************************************************************************/
+
+ajint embPropGetPve(const EmbPPropAmino prop)
+{
+    return prop->pve;
+}
+
+
+
+
+/* @func embPropGetNve *****************************************************
+**
+** Return nve value
+**
+** @param [r] prop [const EmbPPropAmino] Input properties object
+** @return [ajint] nve
+** @@
+******************************************************************************/
+
+ajint embPropGetNve(const EmbPPropAmino prop)
+{
+    return prop->nve;
+}
+
+
+
+
+/* @func embPropGetExtcoeff ***************************************************
+**
+** Return extcoeff value
+**
+** @param [r] prop [const EmbPPropAmino] Input properties object
+** @return [ajint] extcoeff
+** @@
+******************************************************************************/
+
+ajint embPropGetExtcoeff(const EmbPPropAmino prop)
+{
+    return prop->extcoeff;
 }
 
 
@@ -143,14 +503,27 @@ void embPropAminoRead(AjPFile mfptr)
 ** @param [r] s [const char *] sequence
 ** @param [r] start [ajint] start position
 ** @param [r] end [ajint] end position
+** @param [r] mwdata [EmbPPropMolwt const *] molecular weight data
+** @param [r] mono [AjBool] true for monoisotopic values
 **
 ** @return [double] molecular weight
 ** @@
 ******************************************************************************/
 
-double embPropCalcMolwt(const char *s, ajint start, ajint end)
+double embPropCalcMolwt(const char *s, ajint start, ajint end,
+			EmbPPropMolwt const *mwdata, AjBool mono)
 {
-    return embPropCalcMolwtMod(s,start,end,EMBPROPMSTN_H, EMBPROPMSTC_OH );
+    double nmass = 0.;
+    double cmass = 0.;
+
+    nmass = (mono) ? mwdata[EMBPROPHINDEX]->mono :
+	mwdata[EMBPROPHINDEX]->average;
+
+    cmass = (mono) ? mwdata[EMBPROPOINDEX]->mono + nmass :
+	mwdata[EMBPROPOINDEX]->average + nmass;
+    
+
+    return embPropCalcMolwtMod(s,start,end,mwdata,mono,nmass,cmass);
 }
 
 
@@ -164,6 +537,8 @@ double embPropCalcMolwt(const char *s, ajint start, ajint end)
 ** @param [r] s [const char *] sequence
 ** @param [r] start [ajint] start position
 ** @param [r] end [ajint] end position
+** @param [r] mwdata [EmbPPropMolwt const *] molecular weight data
+** @param [r] mono [AjBool] true for monoisotopic values
 ** @param [r] nmass [double] mass of the N-terminal group
 ** @param [r] cmass [double] mass of the C-terminal group
 **
@@ -171,25 +546,30 @@ double embPropCalcMolwt(const char *s, ajint start, ajint end)
 ** @@
 ******************************************************************************/
 
-double embPropCalcMolwtMod(const char *s, ajint start, ajint end, double nmass,
-			   double cmass)
+double embPropCalcMolwtMod(const char *s, ajint start, ajint end,
+			   EmbPPropMolwt const *mwdata, AjBool mono,
+			   double nmass, double cmass)
 {
     const char *p;
     double sum;
     ajint i;
     ajint len;
+    ajint idx;
+    double mw = 0.;
+    
+    len = end - start + 1;
 
-    if(!propInit)
-      ajFatal("Amino Acid data not initialised. Call embPropAminoRead");
-
-    len = end-start+1;
-
-    p = s+start;
+    p = s + start;
     sum = 0.0;
 
     for(i=0;i<len;++i)
-	sum += EmbPropTable[ajAZToInt(toupper((ajint)p[i]))][EMBPROPMOLWT];
-
+    {
+	idx = ajBasecodeToInt(toupper((ajint)p[i]));
+	mw = (mono) ? mwdata[idx]->mono : mwdata[idx]->average;
+	
+	sum += mw;
+    }
+    
     return sum + nmass + cmass;
 }
 
@@ -203,12 +583,14 @@ double embPropCalcMolwtMod(const char *s, ajint start, ajint end, double nmass,
 ** @param [r] s [const char *] sequence
 ** @param [r] start [ajint] start position
 ** @param [r] end [ajint] end position
+** @param [r] aadata [EmbPPropAmino const *] amino acid data
 **
 ** @return [double] molar extinction coefficient
 ** @@
 ******************************************************************************/
 
-double embPropCalcMolextcoeff(const char *s, ajint start, ajint end)
+double embPropCalcMolextcoeff(const char *s, ajint start, ajint end,
+			      EmbPPropAmino const *aadata)
 {
 
     const char *p;
@@ -216,17 +598,13 @@ double embPropCalcMolextcoeff(const char *s, ajint start, ajint end)
     ajint i;
     ajint len;
     
-    if(!propInit)
-	ajFatal("Amino Acid data not initialised. Call embPropAminoRead");
-
     len = end-start+1;
     
     p   = s+start;
     sum = 0.0;
 
     for(i=0;i<len;++i)
-	sum += EmbPropTable[ajAZToInt(toupper((ajint)p[i]))]
-	    [EMBPROPABSORBANCE];
+	sum += (double) aadata[ajBasecodeToInt(toupper((ajint)p[i]))]->extcoeff;
 
     return sum;
 }
@@ -246,7 +624,7 @@ double embPropCalcMolextcoeff(const char *s, ajint start, ajint end)
 
 const char* embPropCharToThree(char c)
 {
-    return embPropIntToThree(ajAZToInt(c));
+    return embPropIntToThree(ajBasecodeToInt(c));
 }
 
 
@@ -294,7 +672,8 @@ const char* embPropIntToThree(ajint c)
 ** @param [r] nterm [AjBool] nterm ragging
 ** @param [r] cterm [AjBool] cterm ragging
 ** @param [r] dorag [AjBool] true if ragging
-
+** @param [r] mwdata [EmbPPropMolwt const *] molecular weight data
+** @param [r] mono [AjBool] true for monoisotopic weights
 **
 ** @return [void]
 ** @@
@@ -305,7 +684,8 @@ void embPropCalcFragments(const char *s, ajint n,
 			  AjBool unfavoured, AjBool overlap,
 			  AjBool allpartials, ajint *ncomp, ajint *npart,
 			  AjPStr *rname, AjBool nterm, AjBool cterm,
-			  AjBool dorag)
+			  AjBool dorag, EmbPPropMolwt const *mwdata,
+			  AjBool mono)
 {
     static const char *PROPENZReagent[]=
     {
@@ -394,13 +774,16 @@ void embPropCalcFragments(const char *s, ajint n,
 
 
     mark = 0;
+
     for(i=0;i<defcnt;++i)  /* Work out true starts, ends and molwts */
     {
 	bwp = mark;
 	ewp = endsa[i];
+
 	if(strchr(PROPENZAminoCarboxyl[n],'N'))
 	    --ewp;
-	molwt=embPropCalcMolwt(s,bwp,ewp);
+
+	molwt=embPropCalcMolwt(s,bwp,ewp,mwdata,mono);
 
 	if(n==PROPENZCNBR)
 	    molwt -= (17.045 + 31.095);
@@ -414,7 +797,7 @@ void embPropCalcFragments(const char *s, ajint n,
 
     if(defcnt)		   /* Special treatment for last fragment   */
     {
-	molwt = embPropCalcMolwt(s,mark,len-1);
+	molwt = embPropCalcMolwt(s,mark,len-1,mwdata,mono);
 	if(n==PROPENZCNBR)
 	    molwt -= (17.045 + 31.095);
 	begsa[i]   = mark;
@@ -431,14 +814,17 @@ void embPropCalcFragments(const char *s, ajint n,
 	{
 	    st = begsa[i];
 	    et = endsa[i];
+
 	    for(it=st+RAG_MINPEPLEN-1; it < et; ++it)
 	    {
 		AJNEW0(fr);
 		fr->start = st;
 		fr->end   = it;
-		fr->molwt = embPropCalcMolwt(s,st,it);
+		fr->molwt = embPropCalcMolwt(s,st,it,mwdata,mono);
+
 		if(n == PROPENZCNBR)
 		    fr->molwt -= (17.045 + 31.095);
+
 		fr->isfrag = ajTrue;
 		ajListPush(*l,(void *)fr);
 	    }
@@ -457,9 +843,11 @@ void embPropCalcFragments(const char *s, ajint n,
 		AJNEW0(fr);
 		fr->start = it;
 		fr->end   = et;
-		fr->molwt = embPropCalcMolwt(s,it,et);
+		fr->molwt = embPropCalcMolwt(s,it,et,mwdata,mono);
+
 		if(n == PROPENZCNBR)
 		    fr->molwt -= (17.045 + 31.095);
+
 		fr->isfrag = ajTrue;
 		ajListPush(*l,(void *)fr);
 	    }
@@ -474,6 +862,7 @@ void embPropCalcFragments(const char *s, ajint n,
     *npart = 0;
 
     lim = defcnt -1;
+
     if(overlap && !allpartials)
     {
 	for(i=0;i<lim;++i)
@@ -483,15 +872,18 @@ void embPropCalcFragments(const char *s, ajint n,
 		st = begsa[i];
 		mt = endsa[i];
 		et = endsa[i+1];
+
 		if(cterm)
 		    for(it=mt+1; it < et; ++it)
 		    {
 			AJNEW0(fr);
 			fr->start = st;
 			fr->end   = it;
-			fr->molwt = embPropCalcMolwt(s,st,it);
+			fr->molwt = embPropCalcMolwt(s,st,it,mwdata,mono);
+
 			if(n == PROPENZCNBR)
 			    fr->molwt -= (17.045 + 31.095);
+
 			fr->isfrag = ajTrue;
 			ajListPush(*l,(void *)fr);
 		    }
@@ -499,7 +891,7 @@ void embPropCalcFragments(const char *s, ajint n,
 
 	    AJNEW0(fr);
 	    fr->isfrag = ajTrue;
-	    fr->molwt = embPropCalcMolwt(s,begsa[i],endsa[i+1]);
+	    fr->molwt = embPropCalcMolwt(s,begsa[i],endsa[i+1],mwdata,mono);
 	    if(n==PROPENZCNBR)
 		fr->molwt -= (17.045 + 31.095);
 	    fr->start = begsa[i];
@@ -513,9 +905,11 @@ void embPropCalcFragments(const char *s, ajint n,
 		    AJNEW0(fr);
 		    fr->start = it;
 		    fr->end   = et;
-		    fr->molwt = embPropCalcMolwt(s,it,et);
+		    fr->molwt = embPropCalcMolwt(s,it,et,mwdata,mono);
+
 		    if(n == PROPENZCNBR)
 			fr->molwt -= (17.045 + 31.095);
+
 		    fr->isfrag = ajTrue;
 		    ajListPush(*l,(void *)fr);
 		}
@@ -533,14 +927,18 @@ void embPropCalcFragments(const char *s, ajint n,
 
     if(allpartials)
     {
+        lim = defcnt;
+
 	for(i=0;i<lim;++i)
 	    for(j=i+1;j<lim;++j)
 	    {
 		AJNEW0(fr);
 		fr->isfrag = ajTrue;
-		fr->molwt = embPropCalcMolwt(s,begsa[i],endsa[j]);
+		fr->molwt = embPropCalcMolwt(s,begsa[i],endsa[j],mwdata,mono);
+
 		if(n==PROPENZCNBR)
 		    fr->molwt -= (17.045 + 31.095);
+
 		fr->start = begsa[i];
 		fr->end   = endsa[j];
 		ajListPush(*pa,(void *)fr);
@@ -681,6 +1079,68 @@ AjPStr embPropProt1to3(AjPSeq seq, ajint pad)
 
 
 
+/* @func embPropProt1to3Rev ****************************************************
+**
+** Creates a a 3-letter sequence protein string from single-letter sequence
+** in the reverse direction.
+** EMBOSS is bad at reading 3-letter sequences, but this may be useful
+** when displaying translations.
+**
+** @param [u] seq [AjPSeq] protein sequence to convert to 3-letter codes
+** @param [r] pad [ajint] number of characters to skip at the start
+**                        of the result
+** @return [AjPStr] string containing 3-letter protein sequence
+** @@
+******************************************************************************/
+
+AjPStr embPropProt1to3Rev(AjPSeq seq, ajint pad)
+{
+    const char *p;
+    const char *p3;
+    AjPStr temp;
+    ajint i=0;
+
+    temp = ajStrNewRes(ajSeqGetLen(seq)*3 + pad+1);
+
+    for(p=ajSeqGetSeqC(seq); *p; p++)
+    {
+	if(*p == '*')
+	    ajStrAppendC(&temp, "***");
+	else if(*p == '.')
+	    ajStrAppendC(&temp, "...");
+	else if(*p == '-')
+	    ajStrAppendC(&temp, "---");
+	else if(!isalpha((ajint)*p))
+	    ajStrAppendC(&temp, "???");
+	else
+	{
+            p3 = embPropCharToThree(*p);
+
+            if(i++)
+            {
+                ajStrAppendK(&temp, *(p3+2));
+                ajStrAppendK(&temp, *(p3+1));
+                ajStrAppendK(&temp, *p3);
+            }
+            else
+            {
+                if(pad >= 2) 
+                    ajStrAppendK(&temp, *(p3+2));
+
+                if(pad >= 1) 
+                    ajStrAppendK(&temp, *(p3+1));
+
+                ajStrAppendK(&temp, *p3);
+            }            
+        }
+    }
+
+    return temp;
+}
+
+
+
+
 /* @func embPropPurine ********************************************************
 **
 ** Returns ajTrue if the input base is a Purine.
@@ -833,6 +1293,9 @@ AjBool embPropTransition(char base1, char base2)
     return (bu1 == bu2);
 }
 
+
+
+
 /* @func embPropFixF *********************************************************
 **
 ** Fix for missing properties data in a float array
@@ -855,21 +1318,21 @@ void embPropFixF(float matrix[], float missing)
 	{
 	    switch (i)
 	    {
-	    case 1:			/* B */
+	    case 1:			/* B: D + N */
 		matrix[i] = ((matrix[3] * dayhoff[3]) +
 			     (matrix[13] * dayhoff[13])) /
 				 (dayhoff[3] + dayhoff[13]);
 		ajDebug("Missing %d '%c' %f %f => %f\n",
 			i, dayhoffstr[i], matrix[3], matrix[13], matrix[i]);
 		break;
-	    case 9:			/* J */
+	    case 9:			/* J: I + L */
 		matrix[i] = ((matrix[8] * dayhoff[8]) +
 			     (matrix[11] * dayhoff[11])) /
 				 (dayhoff[8] + dayhoff[11]);
 		ajDebug("Missing %d '%c' %f %f => %f\n",
 			i, dayhoffstr[i], matrix[8], matrix[11], matrix[i]);
 		break;
-	    case 25:			/* Z */
+	    case 25:			/* Z: E + Q */
 		matrix[i] = ((matrix[4] * dayhoff[4]) +
 			     (matrix[16] * dayhoff[16])) /
 				 (dayhoff[4] + dayhoff[16]);
@@ -890,38 +1353,125 @@ void embPropFixF(float matrix[], float missing)
 	    }
 	}
     }
+
     mtot /= dtot;
 
     for(i=0;i<26;i++)
-    {
-	if(matrix[i] == missing)
+	if(matrix[i] == missing) /* X:average O,U:X */
 	{
 	    matrix[i] = mtot;
 	    ajDebug("Missing %d '%c' unknown %f\n",
 		    i, dayhoffstr[i], matrix[i]);
 	}
-    }
-
 
     return;
 }
-/* @func embPropExit *********************************************************
+
+
+
+
+/* @func embPropNormalF ********************************************************
 **
-** Cleanup of properties data
+** Normalize data values in a float array to have mean 0.0 and
+** standard deviation 1.0
 **
+** Assume the data values represent all values for a population
+** (e.g. values for all standard amino acids) and use
+** new value = (old value - mean) / standard deviation
+**
+** @param [u] matrix [float[]] Matrix
+** @param [r] missing [float] Missing data value
 ** @return [void]
 ******************************************************************************/
 
-void embPropExit(void)
+void embPropNormalF(float matrix[], float missing)
 {
-    ajint i;
-    if(propInit)
-    {
-	for(i=0;i<EMBPROPSIZE;i++)
+    ajuint i;
+
+    double count = 0.0;
+    double total = 0.0;
+    double sumsq = 0.0;
+    double sigma = 0.0;
+    double mean = 0.0;
+    const char* alphabet = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
+
+    for(i=0;i<26;i++)
+	if(matrix[i] != missing)
 	{
-	    AJFREE(EmbPropTable[i]);
-	}
-    }
+            count += 1.0;
+            total += matrix[i];
+            sumsq += matrix[i] * matrix[i];
+        }
+
+    if(!count)
+        return;
+
+    sigma = sqrt(count*sumsq - total*total)/count;
+    mean = total/count;
+
+    ajDebug("matrix normalize mean: %.3f sigma: %.3f\n", mean, sigma);
+
+    for(i=0;i<26;i++)
+	if(matrix[i] != missing)
+        {
+            ajDebug("matrix[%u] %c %.3f", i, alphabet[i], matrix[i]);
+            matrix[i] = (float) ((matrix[i] - mean) / sigma);
+            ajDebug(" => %.3f\n", matrix[i]);
+        }
+
+    return;
+}
+
+
+/* @func embPropAminoDel ******************************************************
+**
+** Delete array of amino acid properties
+**
+** @param [w] thys [EmbPPropAmino**] amino acid properties
+** @return [void]
+******************************************************************************/
+
+void embPropAminoDel(EmbPPropAmino **thys)
+{
+    EmbPPropAmino *pthis = NULL;
+    ajuint i;
+    
+    pthis = *thys;
+
+    for(i=0; i < EMBPROPSIZE; ++i)
+	AJFREE(pthis[i]);
+
+    AJFREE(pthis);
+
+    *thys = NULL;
+
+    return;
+}
+
+
+
+
+/* @func embPropMolwtDel ******************************************************
+**
+** Delete array of molwts
+**
+** @param [w] thys [EmbPPropMolwt**] molwts
+** @return [void]
+******************************************************************************/
+
+void embPropMolwtDel(EmbPPropMolwt **thys)
+{
+    EmbPPropMolwt *pthis = NULL;
+    ajuint i;
+    
+    pthis = *thys;
+
+    for(i=0; i < EMBPROPSIZE + 2; ++i)
+	AJFREE(pthis[i]);
+
+    AJFREE(pthis);
+
+    *thys = NULL;
 
     return;
 }
