@@ -18,6 +18,10 @@
 
 use File::Basename;
 
+%rotations = ("density" => "90<",
+	      "dotmatcher" => "90<",
+	      "pepwheel" => "90>",
+    );
 
 open (LOG,">>makeexample.log") || die "Cannot append to makeexample.log";
 
@@ -285,6 +289,8 @@ foreach $dotest (@dirs) {
 # ignore qualifiers - words starting with a '-'
         if ($f =~ /^-/) {next;}
 # split on '::' to get files embedded in a format::file USA
+        $f =~ s/^[']//;
+        $f =~ s/[']$//;
         if ($f =~ /\:\:/) {
 	    print "CL line=$f\n";
             @fm = split /\:\:/, $f;
@@ -582,15 +588,49 @@ test $dotest hasn't used ", $#answers+1, " answers\n";
 	$file = $path;
 	$file =~ s/^$dir\///;
 
+	$filetype = `file $path`;
+
 # if this a .gif, .ps or .png graphics file?
-	if ($file =~ /\.gif$|\.ps$|\.png$/) {
+	if ($filetype =~ /: GIF image data|: PNG image data|: PostScript /) {
 
 # convert .ps file to gif
 	    $giffile = "";
 	    $origfile = $file;
-	    if ($file =~ /\.ps$/) {
+	    if ($file =~ /([a-z0-9_]+)\.ps$/) {
+		$pname = $1;
 		$giffile = $file;
-		$giffile =~ s/\.ps/.gif/;
+		$giffile =~ s/\.[a-z]*ps2?/.gif/;
+		$rotate = "-90<";
+		if(defined($rotations{$pname})){
+		    $rotate = $rotations{$pname};
+		    print STDERR "rotate '$rotate'\n";
+		}
+# add -delay to see the first page of an animated gif for 10 mins
+		# add -delay to see the first page of an animated gif for 10 mins
+		system("2>&1 convert -delay 65535 -rotate '$rotate' $path $giffile >/dev/null");
+		$file = $giffile;
+		$path = $giffile;
+	    }
+
+	    elsif ($file =~ /\.([a-z]+)ps$/) {
+		$giffile = $file;
+		$giffile =~ s/\.([a-z]+)ps/.$1.gif/;
+		system("2>&1 convert -delay 65535 -rotate '-90<' $path $giffile >/dev/null");
+		$file = $giffile;
+		$path = $giffile;
+	    }
+
+	    elsif ($file =~ /\.ps2$/) {
+		$giffile = $file;
+		$giffile =~ s/\.ps(\d)/.$1.gif/;
+# add -delay to see the first page of an animated gif for 10 mins
+		system("2>&1 convert -delay 65535 -rotate '-90<' $path $giffile >/dev/null");
+		$file = $giffile;
+		$path = $giffile;
+	    }
+	    elsif ($filetype =~ /: PostScript /) {
+		$giffile = $file;
+		$giffile .= ".gif";
 # add -delay to see the first page of an animated gif for 10 mins
 		system("2>&1 convert -delay 65535 -rotate '-90<' $path $giffile >/dev/null");
 		$file = $giffile;
@@ -769,7 +809,8 @@ sub writeUsage {
     $usage =~ s/seqsearch\-[0-9]+[.][0-9]+[.]/seqsearch-1234567890.1234./go;
     $usage =~ s/hmmalign\-[0-9]+[.][0-9]+/hmmalign-1234567890.1234/go;
     $usage =~ s/hmmpfam\-[0-9]+[.][0-9]+/hmmpfam-1234567890.1234/go;
-
+    $usage =~ s/Localtime: ... ... +\d+ [0-9:]+ 2[0-9][0-9][0-9]$/Localtime: Tue Jul 15 12:00:00 2008/gom;
+    $usage =~ s/SUBMITTED iprscan-\d+-\d+/SUBMITTED-iprscan-20080715-12345678/go;
     print OUT $usage;
     close(OUT);
     chmod 0664, $out;	# rw-rw-r--
@@ -786,7 +827,7 @@ sub writeInput {
 
     my $out = "$incdir/$application.input";
     open (OUT, "> $out") || die "Can't open $out";
-    $input =~ s/DATE  [A-Z][a-z][a-z] [A-Z][a-z][a-z] +[0-9]+ [0-9:]+ 200[5-9]/DATE  Sun Jul 15 12:00:00 2007/go;
+    $input =~ s/DATE  [A-Z][a-z][a-z] [A-Z][a-z][a-z] +[0-9]+ [0-9:]+ 200[5-9]/DATE  Tue Jul 15 12:00:00 2008/go;
     print OUT $input;
     close(OUT);
     chmod 0664, $out;	# rw-rw-r--
@@ -804,10 +845,11 @@ sub writeOutput {
     my $out = "$incdir/$application.output";
     open (OUT, "> $out") || die "Can't open $out";
     $output =~ s/\/homes\/pmr\/cvsemboss/\/homes\/user/go;
-    $output =~ s/DATE  [A-Z][a-z][a-z] [A-Z][a-z][a-z] +[0-9]+ [0-9:]+ 200[5-9]/DATE  Sun Jul 15 12:00:00 2007/go;
-    $output =~ s/CreationDate: ... ... +\d+ [0-9:]+ 2[0-9][0-9][0-9]$/CreationDate: Sun Jul 15 12:00:00 2007/gom;
-    $output =~ s/Rundate: ... ... +\d+ 2[0-9][0-9][0-9] [0-9:]+$/Rundate: Sun Jul 15 2007 12:00:00/gom;
-    $output =~ s/\#\#date 2[0-9][0-9][0-9][-][0-9][0-9][-][0-9][0-9]$/\#\#date 2007-07-15/gom;
+    $output =~ s/DATE  [A-Z][a-z][a-z] [A-Z][a-z][a-z] +[0-9]+ [0-9:]+ 200[5-9]/DATE  Tue Jul 15 12:00:00 2008/go;
+    $output =~ s/CreationDate: ... ... +\d+ [0-9:]+ 2[0-9][0-9][0-9]$/CreationDate: Tue Jul 15 12:00:00 2008/gom;
+    $output =~ s/Rundate: ... ... +\d+ 2[0-9][0-9][0-9] [0-9:]+$/Rundate: Tue Jul 15 2008 12:00:00/gom;
+    $output =~ s/Localtime: ... ... +\d+ [0-9:]+ 2[0-9][0-9][0-9]$/Localtime: Tue Jul 15 12:00:00 2008/gom;
+    $output =~ s/\#\#date 2[0-9][0-9][0-9][-][0-9][0-9][-][0-9][0-9]$/\#\#date 2008-07-15/gom;
     $output =~ s/domainalign\-[0-9]+[.][0-9]+[.]/domainalign-1234567890.1234./go;
     $output =~ s/domainrep\-[0-9]+[.][0-9]+[.]/domainrep-1234567890.1234./go;
     $output =~ s/seqalign\-[0-9]+[.][0-9]+[.]/seqalign-1234567890.1234./go;
@@ -815,6 +857,7 @@ sub writeOutput {
     $output =~ s/hmmalign\-[0-9]+[.][0-9]+/hmmalign-1234567890.1234/go;
     $output =~ s/hmmpfam\-[0-9]+[.][0-9]+/hmmpfam-1234567890.1234/go;
     $output =~ s/Time 0\.00[1-5][0-9][0-9][0-9] secs\./Time 0.001999 secs./go;
+    $output =~ s/\%\%Creator: (\S+ [\d.]+) 2[0-9][0-9][0-9]\/[0-9[0-9]\/[0-9[0-9]/Creator: $1 2008\/07\/15/go;
     print OUT $output;
     close(OUT);
     chmod 0664, $out;	# rw-rw-r--
